@@ -2,6 +2,7 @@
 #define METAMODELICA_H
 
 #include <cstdint>
+#include <cstddef>
 #include <string>
 #include <string_view>
 #include <iosfwd>
@@ -10,6 +11,8 @@
 #include <memory>
 #include <initializer_list>
 #include <iterator>
+#include <vector>
+#include <type_traits>
 
 struct record_description;
 
@@ -83,7 +86,8 @@ namespace OpenModelica
         template<typename T> std::vector<T> mapVector() const;
         // Converts an Array or List value to an std::vector<T> using f(value)
         // for each value in the array/list.
-        template<typename T, typename ConvertFunc> std::vector<T> mapVector(ConvertFunc f) const;
+        template<typename ConvertFunc, typename T = typename std::invoke_result<ConvertFunc, Value>::type>
+        std::vector<T> mapVector(ConvertFunc f) const;
 
         // Converts the value using the corresponding Value::toX method for T.
         template<typename T> T to() const;
@@ -252,7 +256,7 @@ namespace OpenModelica
         ConstIterator end() const noexcept;
         ConstIterator cend() const noexcept;
         bool empty() const noexcept;
-        size_t size() const noexcept;
+        std::size_t size() const noexcept;
 
         void cons(Value v) noexcept;
         void* data() const noexcept;
@@ -266,7 +270,7 @@ namespace OpenModelica
           return v;
         }
 
-        template<typename T, typename ConvertFunc>
+        template<typename ConvertFunc, typename T = typename std::invoke_result<ConvertFunc, Value>::type>
         std::vector<T> mapVector(ConvertFunc f) const
         {
           std::vector<T> v;
@@ -300,7 +304,7 @@ namespace OpenModelica
         using pointer           = value_type*;
         using reference         = value_type&;
 
-        IndexedConstIterator(void *value, size_t index) noexcept;
+        IndexedConstIterator(void *value, std::size_t index) noexcept;
 
         value_type operator*() const noexcept;
         Value::ArrowProxy operator->() const noexcept;
@@ -312,7 +316,7 @@ namespace OpenModelica
 
       private:
         void *_value;
-        size_t _index = 0;
+        std::size_t _index = 0;
     };
 
     bool operator== (const IndexedConstIterator &i1, const IndexedConstIterator &i2) noexcept;
@@ -330,10 +334,10 @@ namespace OpenModelica
         IndexedConstIterator end() const noexcept;
         IndexedConstIterator cend() const noexcept;
         bool empty() const noexcept;
-        size_t size() const noexcept;
+        std::size_t size() const noexcept;
 
-        Value operator[](size_t index) const noexcept;
-        Value at(size_t index) const;
+        Value operator[](std::size_t index) const noexcept;
+        Value at(std::size_t index) const;
         void* data() const noexcept;
 
         template<typename T>
@@ -345,7 +349,7 @@ namespace OpenModelica
           return v;
         }
 
-        template<typename T, typename ConvertFunc>
+        template<typename ConvertFunc, typename T = typename std::invoke_result<ConvertFunc, Value>::type>
         std::vector<T> mapVector(ConvertFunc f) const
         {
           std::vector<T> v;
@@ -380,10 +384,10 @@ namespace OpenModelica
         IndexedConstIterator cbegin() const noexcept;
         IndexedConstIterator end() const noexcept;
         IndexedConstIterator cend() const noexcept;
-        size_t size() const noexcept;
+        std::size_t size() const noexcept;
 
-        Value operator[](size_t index) const noexcept;
-        Value at(size_t index) const;
+        Value operator[](std::size_t index) const noexcept;
+        Value at(std::size_t index) const;
         void* data() const noexcept;
 
       private:
@@ -414,11 +418,11 @@ namespace OpenModelica
         IndexedConstIterator cbegin() const noexcept;
         IndexedConstIterator end() const noexcept;
         IndexedConstIterator cend() const noexcept;
-        size_t size() const noexcept;
+        std::size_t size() const noexcept;
 
         Value operator[](std::string_view name) const noexcept;
-        Value operator[](size_t index) const noexcept;
-        Value at(size_t index) const;
+        Value operator[](std::size_t index) const noexcept;
+        Value at(std::size_t index) const;
         IndexedConstIterator find(std::string_view name) const noexcept;
         bool contains(std::string_view name) const noexcept;
         void* data() const noexcept;
@@ -453,10 +457,10 @@ namespace OpenModelica
       return isList() ? toList().mapVector<T>() : toArray().mapVector<T>();
     }
 
-    template<typename T, typename ConvertFunc>
+    template<typename ConvertFunc, typename T>
     std::vector<T> Value::mapVector(ConvertFunc f) const
     {
-      return isList() ? toList().mapVector<T>(f) : toArray().mapVector<T>(f);
+      return isList() ? toList().mapVector(f) : toArray().mapVector(f);
     }
 
     template<typename T>
