@@ -77,9 +77,18 @@ typedef struct VAR_INFO
   FILE_INFO info;
 } VAR_INFO;
 
+typedef enum
+{
+  EQUATION_SECTION_UNKNOWN,
+  EQUATION_SECTION_INIT_LAMBDA0,
+  EQUATION_SECTION_INITIAL,
+  EQUATION_SECTION_REGULAR
+} EQUATION_SECTION;
+
 typedef struct EQUATION_INFO
 {
   int id;
+  EQUATION_SECTION section;
   int profileBlockIndex;
   int parent;
   int numVar;
@@ -286,6 +295,7 @@ typedef struct STATIC_STRING_DATA
 } STATIC_STRING_DATA;
 
 typedef int (*analyticalJacobianColumn_func_ptr)(DATA* data, threadData_t* threadData, ANALYTIC_JACOBIAN* thisJacobian, ANALYTIC_JACOBIAN* parentJacobian);
+typedef int (*initialAnalyticalJacobian_func_ptr)(DATA* data, threadData_t* threadData, ANALYTIC_JACOBIAN* jacobian);
 
 /**
  * @brief User data provided to residual functions.
@@ -328,12 +338,13 @@ typedef struct NONLINEAR_SYSTEM_DATA
    * if analyticalJacobianColumn == NULL no analyticalJacobian is available
    */
   analyticalJacobianColumn_func_ptr analyticalJacobianColumn;
-  int (*initialAnalyticalJacobian)(DATA* data, threadData_t* threadData, ANALYTIC_JACOBIAN* jacobian);
+  initialAnalyticalJacobian_func_ptr initialAnalyticalJacobian;
   modelica_integer jacobianIndex;
 
   SPARSE_PATTERN *sparsePattern;       /* sparse pattern if no jacobian is available */
   modelica_boolean isPatternAvailable;
-  NONLINEAR_PATTERN* nonlinearPattern;
+  NONLINEAR_PATTERN *nonlinearPattern;
+  int *eqn_simcode_indices;
 
   void (*residualFunc)(RESIDUAL_USERDATA* userData, const double* x, double* res, const int* flag);
   int (*residualFuncConstraints)(RESIDUAL_USERDATA* userData, const double*, double*, const int*);
@@ -408,7 +419,7 @@ typedef struct LINEAR_SYSTEM_DATA
   void (*setBElement)(int row, double value, LINEAR_SYSTEM_DATA* linearSystemData, threadData_t* threadData);
 
   analyticalJacobianColumn_func_ptr analyticalJacobianColumn;
-  int (*initialAnalyticalJacobian)(DATA* data, threadData_t* threadData, ANALYTIC_JACOBIAN* jacobian);
+  initialAnalyticalJacobian_func_ptr initialAnalyticalJacobian;
 
   void (*residualFunc)(RESIDUAL_USERDATA* userData, const double* x, double* res, const int* flag);
   void (*initializeStaticLSData)(DATA* data, threadData_t* threadData, LINEAR_SYSTEM_DATA* linearSystemData, modelica_boolean initSparsePattern);
@@ -499,7 +510,7 @@ typedef struct STATE_SET_DATA
    * if analyticalJacobianColumn == NULL no analyticalJacobian is available
    */
   analyticalJacobianColumn_func_ptr analyticalJacobianColumn;
-  int (*initialAnalyticalJacobian)(DATA* data, threadData_t* threadData, ANALYTIC_JACOBIAN* jacobian);
+  initialAnalyticalJacobian_func_ptr initialAnalyticalJacobian;
   modelica_integer jacobianIndex;
 } STATE_SET_DATA;
 #else
@@ -576,6 +587,13 @@ typedef struct MODEL_DATA
   long nBaseClocks;                    /* total number of base-clocks*/
 
   fortran_integer nStates;
+
+  /* numbers of unscalarized variables (arrays counted as one variable, used for index map) */
+  size_t nVariablesRealArray;
+  size_t nVariablesIntegerArray;
+  size_t nVariablesBooleanArray;
+  size_t nVariablesStringArray;
+
   long nVariablesReal;                 /* all Real Variables of the model (states, statesderivatives, algebraics, real discretes) */
   long nDiscreteReal;                  /* only all _discrete_ reals */
   long nVariablesInteger;
@@ -761,6 +779,12 @@ typedef struct SIMULATION_INFO
   modelica_real* states_left;          /* work array for findRoot in event.c */
   modelica_real* states_right;         /* work array for findRoot in event.c */
 
+  /* index map: arr_idx -> start_idx */
+  size_t* realVarsIndex;
+  size_t* integerVarsIndex;
+  size_t* booleanVarsIndex;
+  size_t* stringVarsIndex;
+
   /* old vars for event handling */
   modelica_real timeValueOld;
   modelica_real* realVarsOld;
