@@ -36,7 +36,7 @@
 #include "Modeling/Commands.h"
 
 RectangleAnnotation::RectangleAnnotation(QString annotation, GraphicsView *pGraphicsView)
-  : ShapeAnnotation(false, pGraphicsView, 0, 0)
+  : ShapeAnnotation(false, pGraphicsView, 0)
 {
   mpOriginItem = new OriginItem(this);
   mpOriginItem->setPassive();
@@ -51,7 +51,7 @@ RectangleAnnotation::RectangleAnnotation(QString annotation, GraphicsView *pGrap
 }
 
 RectangleAnnotation::RectangleAnnotation(ModelInstance::Rectangle *pRectangle, bool inherited, GraphicsView *pGraphicsView)
-  : ShapeAnnotation(inherited, pGraphicsView, 0, 0)
+  : ShapeAnnotation(inherited, pGraphicsView, 0)
 {
   mpOriginItem = new OriginItem(this);
   mpOriginItem->setPassive();
@@ -66,14 +66,6 @@ RectangleAnnotation::RectangleAnnotation(ModelInstance::Rectangle *pRectangle, b
   setShapeFlags(true);
 }
 
-RectangleAnnotation::RectangleAnnotation(ShapeAnnotation *pShapeAnnotation, Element *pParent)
-  : ShapeAnnotation(pShapeAnnotation, pParent)
-{
-  mpOriginItem = 0;
-  updateShape(pShapeAnnotation);
-  applyTransformation();
-}
-
 RectangleAnnotation::RectangleAnnotation(ModelInstance::Rectangle *pRectangle, Element *pParent)
   : ShapeAnnotation(pParent)
 {
@@ -89,19 +81,16 @@ RectangleAnnotation::RectangleAnnotation(ModelInstance::Rectangle *pRectangle, E
   applyTransformation();
 }
 
-RectangleAnnotation::RectangleAnnotation(ShapeAnnotation *pShapeAnnotation, GraphicsView *pGraphicsView)
-  : ShapeAnnotation(true, pGraphicsView, pShapeAnnotation, 0)
+RectangleAnnotation::RectangleAnnotation(ShapeAnnotation *pShapeAnnotation, Element *pParent)
+  : ShapeAnnotation(pParent)
 {
-  mpOriginItem = new OriginItem(this);
-  mpOriginItem->setPassive();
+  mpOriginItem = 0;
   updateShape(pShapeAnnotation);
-  setShapeFlags(true);
-  mpGraphicsView->addItem(this);
-  mpGraphicsView->addItem(mpOriginItem);
+  applyTransformation();
 }
 
 RectangleAnnotation::RectangleAnnotation(Element *pParent)
-  : ShapeAnnotation(0, pParent)
+  : ShapeAnnotation(pParent)
 {
   mpOriginItem = 0;
   // set the default values
@@ -126,7 +115,7 @@ RectangleAnnotation::RectangleAnnotation(Element *pParent)
  * \param pGraphicsView
  */
 RectangleAnnotation::RectangleAnnotation(GraphicsView *pGraphicsView)
-  : ShapeAnnotation(true, pGraphicsView, 0, 0)
+  : ShapeAnnotation(true, pGraphicsView, 0)
 {
   mpOriginItem = 0;
   // set the default values
@@ -195,8 +184,7 @@ void RectangleAnnotation::paint(QPainter *painter, const QStyleOptionGraphicsIte
   if (mVisible) {
     // state machine visualization
     if (mpParentComponent && mpParentComponent->getGraphicsView()->isVisualizationView()
-        && ((mpParentComponent->getGraphicsView()->getModelWidget()->isNewApi() && mpParentComponent->getModel() && mpParentComponent->getModel()->getAnnotation()->isState())
-            || (mpParentComponent->getLibraryTreeItem() && mpParentComponent->getLibraryTreeItem()->isState()))) {
+        && (mpParentComponent->getModel() && mpParentComponent->getModel()->getAnnotation()->isState())) {
       if (mpParentComponent->isActiveState()) {
         painter->setOpacity(1.0);
       } else {
@@ -285,24 +273,3 @@ ModelInstance::Extend *RectangleAnnotation::getExtend() const
 {
   return mpRectangle->getParentExtend();
 }
-
-/*!
- * \brief RectangleAnnotation::duplicate
- * Duplicates the shape.
- */
-void RectangleAnnotation::duplicate()
-{
-  RectangleAnnotation *pRectangleAnnotation = new RectangleAnnotation("", mpGraphicsView);
-  pRectangleAnnotation->updateShape(this);
-  QPointF gridStep(mpGraphicsView->mMergedCoOrdinateSystem.getHorizontalGridStep() * 5,
-                   mpGraphicsView->mMergedCoOrdinateSystem.getVerticalGridStep() * 5);
-  pRectangleAnnotation->setOrigin(mOrigin + gridStep);
-  pRectangleAnnotation->drawCornerItems();
-  pRectangleAnnotation->setCornerItemsActiveOrPassive();
-  pRectangleAnnotation->applyTransformation();
-  pRectangleAnnotation->update();
-  mpGraphicsView->getModelWidget()->getUndoStack()->push(new AddShapeCommand(pRectangleAnnotation));
-  mpGraphicsView->getModelWidget()->getLibraryTreeItem()->emitShapeAdded(pRectangleAnnotation, mpGraphicsView);
-  setSelected(false);
-  pRectangleAnnotation->setSelected(true);
-}
