@@ -48,7 +48,7 @@
  * \param pGraphicsView - pointer to GraphicsView
  */
 TextAnnotation::TextAnnotation(QString annotation, GraphicsView *pGraphicsView)
-  : ShapeAnnotation(false, pGraphicsView, 0, 0)
+  : ShapeAnnotation(false, pGraphicsView, 0)
 {
   mpElement = 0;
   mpOriginItem = new OriginItem(this);
@@ -64,7 +64,7 @@ TextAnnotation::TextAnnotation(QString annotation, GraphicsView *pGraphicsView)
 }
 
 TextAnnotation::TextAnnotation(ModelInstance::Text *pText, bool inherited, GraphicsView *pGraphicsView)
-  : ShapeAnnotation(inherited, pGraphicsView, 0, 0)
+  : ShapeAnnotation(inherited, pGraphicsView, 0)
 {
   mpElement = 0;
   mpOriginItem = new OriginItem(this);
@@ -80,15 +80,6 @@ TextAnnotation::TextAnnotation(ModelInstance::Text *pText, bool inherited, Graph
   setShapeFlags(true);
 }
 
-TextAnnotation::TextAnnotation(ShapeAnnotation *pShapeAnnotation, Element *pParent)
-  : ShapeAnnotation(pShapeAnnotation, pParent), mpElement(pParent)
-{
-  mpOriginItem = 0;
-  updateShape(pShapeAnnotation);
-  initUpdateTextString();
-  applyTransformation();
-}
-
 TextAnnotation::TextAnnotation(ModelInstance::Text *pText, Element *pParent)
   : ShapeAnnotation(pParent), mpElement(pParent)
 {
@@ -104,20 +95,17 @@ TextAnnotation::TextAnnotation(ModelInstance::Text *pText, Element *pParent)
   applyTransformation();
 }
 
-TextAnnotation::TextAnnotation(ShapeAnnotation *pShapeAnnotation, GraphicsView *pGraphicsView)
-  : ShapeAnnotation(true, pGraphicsView, pShapeAnnotation, 0)
+TextAnnotation::TextAnnotation(ShapeAnnotation *pShapeAnnotation, Element *pParent)
+  : ShapeAnnotation(pParent), mpElement(pParent)
 {
-  mpElement = 0;
-  mpOriginItem = new OriginItem(this);
-  mpOriginItem->setPassive();
+  mpOriginItem = 0;
   updateShape(pShapeAnnotation);
-  setShapeFlags(true);
-  mpGraphicsView->addItem(this);
-  mpGraphicsView->addItem(mpOriginItem);
+  initUpdateTextString();
+  applyTransformation();
 }
 
 TextAnnotation::TextAnnotation(Element *pParent)
-  : ShapeAnnotation(0, pParent), mpElement(pParent)
+  : ShapeAnnotation(pParent), mpElement(pParent)
 {
   mpOriginItem = 0;
   // set the default values
@@ -134,7 +122,7 @@ TextAnnotation::TextAnnotation(Element *pParent)
 }
 
 TextAnnotation::TextAnnotation(QString annotation, LineAnnotation *pLineAnnotation)
-  : ShapeAnnotation(0, pLineAnnotation)
+  : ShapeAnnotation(pLineAnnotation)
 {
   mpElement = 0;
   mpOriginItem = 0;
@@ -189,7 +177,7 @@ TextAnnotation::TextAnnotation(ModelInstance::Text *pText, LineAnnotation *pLine
  * \param pGraphicsView
  */
 TextAnnotation::TextAnnotation(GraphicsView *pGraphicsView)
-  : ShapeAnnotation(true, pGraphicsView, 0, 0)
+  : ShapeAnnotation(true, pGraphicsView, 0)
 {
   mpElement = 0;
   mpOriginItem = 0;
@@ -334,8 +322,7 @@ void TextAnnotation::paint(QPainter *painter, const QStyleOptionGraphicsItem *op
     // state machine visualization
     // text annotation on a element
     if (mpElement && mpElement->getGraphicsView()->isVisualizationView()
-        && ((mpElement->getGraphicsView()->getModelWidget()->isNewApi() && mpElement->getModel() && mpElement->getModel()->getAnnotation()->isState())
-            || (mpElement->getLibraryTreeItem() && mpElement->getLibraryTreeItem()->isState()))) {
+        && (mpElement->getModel() && mpElement->getModel()->getAnnotation()->isState())) {
       if (mpElement->isActiveState()) {
         painter->setOpacity(1.0);
       } else {
@@ -434,11 +421,11 @@ void TextAnnotation::drawAnnotation(QPainter *painter)
     font.setPointSizeF(qMax(fontSizeFactor, Helper::minimumTextFontSize));
     painter->setFont(font);
   }
-  /* Try to get the elided text if calculated font size <= Helper::minimumTextFontSize
-   * OR if font size is absolute and text is not multiline.
+  /* Try to get the elided text if calculated ((font size <= Helper::minimumTextFontSize OR if font size is absolute) AND text is not multiline).
+   * Issue #8383 and #12754
    */
   QString textToDraw = textString;
-  if (mappedBoundingRect.width() > 1 && ((mFontSize <= 0 && painter->font().pointSizeF() <= Helper::minimumTextFontSize) || (mFontSize > 0 && !Utilities::isMultiline(textString)))) {
+  if (mappedBoundingRect.width() > 1 && ((mFontSize <= 0 && painter->font().pointSizeF() <= Helper::minimumTextFontSize) || (mFontSize > 0)) && !Utilities::isMultiline(textString)) {
     QFontMetrics fontMetrics(painter->font());
     textToDraw = fontMetrics.elidedText(textString, Qt::ElideRight, mappedBoundingRect.width());
     // if we get "..." i.e., QChar(0x2026) as textToDraw then don't draw anything
@@ -550,7 +537,6 @@ void TextAnnotation::initUpdateTextString()
   if (mpElement) {
     if (mOriginalTextString.contains("%")) {
       updateTextString();
-      connect(mpElement, SIGNAL(displayTextChanged()), SLOT(updateTextString()), Qt::UniqueConnection);
     }
   }
 }
@@ -577,25 +563,13 @@ void TextAnnotation::updateTextStringHelper(QRegExp regExp)
           QString textValue = parameterValue.first;
           QPair<QString, bool> unit = mpElement->getRootParentElement()->getParameterModifierValue(variable, "unit");
           QPair<QString, bool> displayUnit = mpElement->getRootParentElement()->getParameterModifierValue(variable, "displayUnit");
-          if (MainWindow::instance()->isNewApi()) {
-            ModelInstance::Component* pModelComponent = Element::getModelComponentByName(mpElement->getRootParentElement()->getModel(), variable);
-            if (pModelComponent) {
-              if (!displayUnit.second) {
-                displayUnit = pModelComponent->getModifierValueFromType(QStringList() << "displayUnit");
-              }
-              if (!unit.second) {
-                unit = pModelComponent->getModifierValueFromType(QStringList() << "unit");
-              }
+          ModelInstance::Component* pModelComponent = Element::getModelComponentByName(mpElement->getRootParentElement()->getModel(), variable);
+          if (pModelComponent) {
+            if (!displayUnit.second) {
+              displayUnit = pModelComponent->getModifierValueFromType(QStringList() << "displayUnit");
             }
-          } else {
-            Element *pElement = mpElement->getRootParentElement()->getElementByName(variable);
-            if (pElement) {
-              if (displayUnit.first.isEmpty()) {
-                displayUnit.first = pElement->getDerivedClassModifierValue("displayUnit");
-              }
-              if (unit.first.isEmpty()) {
-                unit.first = pElement->getDerivedClassModifierValue("unit");
-              }
+            if (!unit.second) {
+              unit = pModelComponent->getModifierValueFromType(QStringList() << "unit");
             }
           }
           // if display unit is still empty then use unit
@@ -665,7 +639,11 @@ void TextAnnotation::updateTextString()
       return;
     }
     if (mTextString.toLower().contains("%name")) {
-      mTextString.replace(QRegExp("%name"), mpElement->getName());
+      QString name = mpElement->getName();
+      if (mpElement->getModelComponent() && mpElement->getModelComponent()->getDimensions().isArray()) {
+        name.append("[" % mpElement->getModelComponent()->getDimensions().getTypedDimensionsString() % "]");
+      }
+      mTextString.replace(QRegExp("%name"), name);
     }
     if (mTextString.toLower().contains("%class")) {
       mTextString.replace(QRegExp("%class"), mpElement->getClassName());
@@ -683,24 +661,3 @@ void TextAnnotation::updateTextString()
     }
   }
 }
-
-/*!
- * \brief TextAnnotation::duplicate
- * Duplicates the shape.
- */
-void TextAnnotation::duplicate()
-{
-  TextAnnotation *pTextAnnotation = new TextAnnotation("", mpGraphicsView);
-  pTextAnnotation->updateShape(this);
-  QPointF gridStep(mpGraphicsView->mMergedCoOrdinateSystem.getHorizontalGridStep() * 5,
-                   mpGraphicsView->mMergedCoOrdinateSystem.getVerticalGridStep() * 5);
-  pTextAnnotation->setOrigin(mOrigin + gridStep);
-  pTextAnnotation->drawCornerItems();
-  pTextAnnotation->setCornerItemsActiveOrPassive();
-  pTextAnnotation->applyTransformation();
-  pTextAnnotation->update();
-  mpGraphicsView->getModelWidget()->getUndoStack()->push(new AddShapeCommand(pTextAnnotation));
-  mpGraphicsView->getModelWidget()->getLibraryTreeItem()->emitShapeAdded(pTextAnnotation, mpGraphicsView);
-  setSelected(false);
-  pTextAnnotation->setSelected(true);
-}
