@@ -168,8 +168,8 @@ void Transformation::parseTransformation(const ModelInstance::PlacementAnnotatio
   mRotateAngleDiagram = transformation.getRotation();
   mRotateAngleDiagram.evaluate(placementAnnotation.getParentModel());
   // map values from element coordinate system to DiagramMap extent
-  if (pExtend && pExtend->getAnnotation()->getDiagramMap().hasExtent()) {
-    ExtentAnnotation extendsCoOrdinateExtents = pExtend->getAnnotation()->getDiagramMap().getExtent();
+  if (pExtend && pExtend->getIconDiagramMapHasExtent(false)) {
+    ExtentAnnotation extendsCoOrdinateExtents = pExtend->getIconDiagramMapExtent(false);
     if (elementCoordinateSystemExtent.size() > 1 && extendsCoOrdinateExtents.size() > 1) {
       const qreal x1 = elementCoordinateSystemExtent.at(0).x();
       const qreal y1 = elementCoordinateSystemExtent.at(0).y();
@@ -182,23 +182,22 @@ void Transformation::parseTransformation(const ModelInstance::PlacementAnnotatio
       const qreal y4 = extendsCoOrdinateExtents.at(1).y();
 
       QPointF origin;
-      origin.setX(Utilities::mapToCoOrdinateSystem(mOriginDiagram.x(), x1, x2, x3, x4));
-      origin.setY(Utilities::mapToCoOrdinateSystem(mOriginDiagram.y(), y1, y2, y3, y4));
+      origin.setX(Utilities::mapToCoordinateSystem(mOriginDiagram.x(), x1, x2, x3, x4));
+      origin.setY(Utilities::mapToCoordinateSystem(mOriginDiagram.y(), y1, y2, y3, y4));
       mOriginDiagram = origin;
 
-
       QVector<QPointF> extent;
       QPointF point;
-      point.setX(Utilities::mapToCoOrdinateSystem(mExtentDiagram.at(0).x(), x1, x2, x3, x4));
-      point.setY(Utilities::mapToCoOrdinateSystem(mExtentDiagram.at(0).y(), y1, y2, y3, y4));
+      point.setX(Utilities::mapToCoordinateSystem(mExtentDiagram.at(0).x(), x1, x2, x3, x4));
+      point.setY(Utilities::mapToCoordinateSystem(mExtentDiagram.at(0).y(), y1, y2, y3, y4));
       extent.append(point);
-      point.setX(Utilities::mapToCoOrdinateSystem(mExtentDiagram.at(1).x(), x1, x2, x3, x4));
-      point.setY(Utilities::mapToCoOrdinateSystem(mExtentDiagram.at(1).y(), y1, y2, y3, y4));
+      point.setX(Utilities::mapToCoordinateSystem(mExtentDiagram.at(1).x(), x1, x2, x3, x4));
+      point.setY(Utilities::mapToCoordinateSystem(mExtentDiagram.at(1).y(), y1, y2, y3, y4));
       extent.append(point);
       mExtentDiagram = extent;
 
-      mExtentCenterDiagram.setX(Utilities::mapToCoOrdinateSystem(mExtentCenterDiagram.x(), x1, x2, x3, x4));
-      mExtentCenterDiagram.setY(Utilities::mapToCoOrdinateSystem(mExtentCenterDiagram.y(), y1, y2, y3, y4));
+      mExtentCenterDiagram.setX(Utilities::mapToCoordinateSystem(mExtentCenterDiagram.x(), x1, x2, x3, x4));
+      mExtentCenterDiagram.setY(Utilities::mapToCoordinateSystem(mExtentCenterDiagram.y(), y1, y2, y3, y4));
     }
   }
   // icon transformation
@@ -212,8 +211,8 @@ void Transformation::parseTransformation(const ModelInstance::PlacementAnnotatio
   mRotateAngleIcon = iconTransformation.getRotation();
   mRotateAngleIcon.evaluate(placementAnnotation.getParentModel());
   // map values from element coordinate system to IconMap extent.
-  if (pExtend && pExtend->getAnnotation()->getIconMap().hasExtent()) {
-    ExtentAnnotation extendsCoOrdinateExtents = pExtend->getAnnotation()->getIconMap().getExtent();
+  if (pExtend && pExtend->getIconDiagramMapHasExtent(true)) {
+    ExtentAnnotation extendsCoOrdinateExtents = pExtend->getIconDiagramMapExtent(true);
     if (elementCoordinateSystemExtent.size() > 1 && extendsCoOrdinateExtents.size() > 1) {
       const qreal x1 = elementCoordinateSystemExtent.at(0).x();
       const qreal y1 = elementCoordinateSystemExtent.at(0).y();
@@ -226,22 +225,22 @@ void Transformation::parseTransformation(const ModelInstance::PlacementAnnotatio
       const qreal y4 = extendsCoOrdinateExtents.at(1).y();
 
       QPointF origin;
-      origin.setX(Utilities::mapToCoOrdinateSystem(mOriginIcon.x(), x1, x2, x3, x4));
-      origin.setY(Utilities::mapToCoOrdinateSystem(mOriginIcon.y(), y1, y2, y3, y4));
+      origin.setX(Utilities::mapToCoordinateSystem(mOriginIcon.x(), x1, x2, x3, x4));
+      origin.setY(Utilities::mapToCoordinateSystem(mOriginIcon.y(), y1, y2, y3, y4));
       mOriginIcon = origin;
 
       QVector<QPointF> extent;
       QPointF point;
-      point.setX(Utilities::mapToCoOrdinateSystem(mExtentIcon.at(0).x(), x1, x2, x3, x4));
-      point.setY(Utilities::mapToCoOrdinateSystem(mExtentIcon.at(0).y(), y1, y2, y3, y4));
+      point.setX(Utilities::mapToCoordinateSystem(mExtentIcon.at(0).x(), x1, x2, x3, x4));
+      point.setY(Utilities::mapToCoordinateSystem(mExtentIcon.at(0).y(), y1, y2, y3, y4));
       extent.append(point);
-      point.setX(Utilities::mapToCoOrdinateSystem(mExtentIcon.at(1).x(), x1, x2, x3, x4));
-      point.setY(Utilities::mapToCoOrdinateSystem(mExtentIcon.at(1).y(), y1, y2, y3, y4));
+      point.setX(Utilities::mapToCoordinateSystem(mExtentIcon.at(1).x(), x1, x2, x3, x4));
+      point.setY(Utilities::mapToCoordinateSystem(mExtentIcon.at(1).y(), y1, y2, y3, y4));
       extent.append(point);
       mExtentIcon = extent;
 
-      mExtentCenterIcon.setX(Utilities::mapToCoOrdinateSystem(mExtentCenterIcon.x(), x1, x2, x3, x4));
-      mExtentCenterIcon.setY(Utilities::mapToCoOrdinateSystem(mExtentCenterIcon.y(), y1, y2, y3, y4));
+      mExtentCenterIcon.setX(Utilities::mapToCoordinateSystem(mExtentCenterIcon.x(), x1, x2, x3, x4));
+      mExtentCenterIcon.setY(Utilities::mapToCoordinateSystem(mExtentCenterIcon.y(), y1, y2, y3, y4));
     }
   }
 }
@@ -258,11 +257,13 @@ void Transformation::updateTransformation(const Transformation &transformation)
   mExtentDiagram = transformation.getExtentDiagram();
   mRotateAngleDiagram = transformation.getRotateAngleDiagram();
   mPositionDiagram = transformation.getPositionDiagram();
+  mExtentCenterDiagram = transformation.getExtentCenterDiagram();
   mVisibleIcon = transformation.getVisibleIcon();
   mOriginIcon = transformation.getOriginIcon();
   mExtentIcon = transformation.getExtentIcon();
   mRotateAngleIcon = transformation.getRotateAngleIcon();
   mPositionIcon = transformation.getPositionIcon();
+  mExtentCenterIcon = transformation.getExtentCenterIcon();
 }
 
 QTransform Transformation::getTransformationMatrix()
@@ -329,6 +330,20 @@ QPointF Transformation::getPosition()
   }
 }
 
+void Transformation::setExtentCenter(QPointF extentCenter)
+{
+  switch (mViewType) {
+    case StringHandler::Icon:
+      setExtentCenterIcon(extentCenter);
+      break;
+    case StringHandler::Diagram:
+    case StringHandler::ModelicaText:
+    default:
+      setExtentCenterDiagram(extentCenter);
+      break;
+  }
+}
+
 bool Transformation::operator==(const Transformation &transformation) const
 {
   return (transformation.getVisible() == this->getVisible()) &&
