@@ -464,7 +464,7 @@ void DocumentationWidget::showDocumentation(LibraryTreeItem *pLibraryTreeItem)
 {
 #ifndef OM_DISABLE_DOCUMENTATION
   // We only support documentation of Modelica classes.
-  if (pLibraryTreeItem->getLibraryType() != LibraryTreeItem::Modelica) {
+  if (!pLibraryTreeItem->isModelica()) {
     return;
   }
   // if documentation is proctected then do not show it.
@@ -501,10 +501,11 @@ void DocumentationWidget::showDocumentation(LibraryTreeItem *pLibraryTreeItem)
     while (mpDocumentationHistoryList->count() > (mDocumentationHistoryPos+1)) {
       mpDocumentationHistoryList->removeLast();
     }
+    /* remove if url exists */
+    removeDocumentationHistory(pLibraryTreeItem);
     /* append new url */
     mpDocumentationHistoryList->append(DocumentationHistory(pLibraryTreeItem));
     mDocumentationHistoryPos++;
-    connect(pLibraryTreeItem, SIGNAL(unLoaded()), SLOT(updateDocumentationHistory()));
   }
 
   updatePreviousNextButtons();
@@ -617,6 +618,35 @@ void DocumentationWidget::saveScrollPosition()
   }
 }
 
+/*!
+ * \brief DocumentationWidget::updateDocumentationHistory
+ * \param pLibraryTreeItem
+ * Removes the corresponding LibraryTreeItem from the DocumentationHistory.
+ */
+void DocumentationWidget::updateDocumentationHistory(LibraryTreeItem *pLibraryTreeItem)
+{
+  if (pLibraryTreeItem) {
+    if (removeDocumentationHistory(pLibraryTreeItem)) {
+      updatePreviousNextButtons();
+      if (mDocumentationHistoryPos > -1) {
+        cancelDocumentation();
+        LibraryTreeModel *pLibraryTreeModel = MainWindow::instance()->getLibraryWidget()->getLibraryTreeModel();
+        pLibraryTreeModel->showModelWidget(mpDocumentationHistoryList->at(mDocumentationHistoryPos).mpLibraryTreeItem);
+      } else {
+        mpEditInfoAction->setDisabled(true);
+        mpEditRevisionsAction->setDisabled(true);
+        mpEditInfoHeaderAction->setDisabled(true);
+        mpSaveAction->setDisabled(true);
+        mpCancelAction->setDisabled(true);
+        mpDocumentationViewer->setHtml(""); // clear if we don't have any documentation to show
+        mpDocumentationViewerFrame->show();
+        mpEditorsWidget->hide();
+        mEditType = EditType::None;
+      }
+    }
+  }
+}
+
 /*!
  * \brief DocumentationWidget::createPixmapForToolButton
  * Creates a new pixmap which contains the QIcon and the QColor in the bottom.
@@ -668,7 +698,7 @@ void DocumentationWidget::writeDocumentationFile(QString documentation)
   /* Create a local file with the html we want to view as otherwise JavaScript does not run properly. */
   mDocumentationFile.open(QIODevice::WriteOnly);
   QTextStream out(&mDocumentationFile);
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
   out.setEncoding(QStringConverter::Utf8);
 #else
   out.setCodec(Helper::utf8.toUtf8().constData());
@@ -704,16 +734,20 @@ bool DocumentationWidget::isLinkSelected()
 }
 
 /*!
- * \brief DocumentationWidget::updateDocumentationHistory
+ * \brief DocumentationWidget::removeDocumentationHistory
+ * Removes the LibraryTreeItem from the documentation history.
  * \param pLibraryTreeItem
- * Removes the corresponding LibraryTreeItem from the DocumentationHistory.
+ * \return true if removed
  */
-void DocumentationWidget::updateDocumentationHistory(LibraryTreeItem *pLibraryTreeItem)
+bool DocumentationWidget::removeDocumentationHistory(LibraryTreeItem *pLibraryTreeItem)
 {
-  if (pLibraryTreeItem) {
-    int index = mpDocumentationHistoryList->indexOf(DocumentationHistory(pLibraryTreeItem));
+  int index = -1;
+  bool removed = false;
+  do {
+    index = mpDocumentationHistoryList->indexOf(DocumentationHistory(pLibraryTreeItem));
     if (index > -1) {
       mpDocumentationHistoryList->removeOne(DocumentationHistory(pLibraryTreeItem));
+      removed = true;
       if (index == mDocumentationHistoryPos) {
         if (!(index == 0 && !mpDocumentationHistoryList->isEmpty())) {
           mDocumentationHistoryPos--;
@@ -723,24 +757,10 @@ void DocumentationWidget::updateDocumentationHistory(LibraryTreeItem *pLibraryTr
       } else if (index > mDocumentationHistoryPos) {
         // do nothing
       }
-      updatePreviousNextButtons();
-      if (mDocumentationHistoryPos > -1) {
-        cancelDocumentation();
-        LibraryTreeModel *pLibraryTreeModel = MainWindow::instance()->getLibraryWidget()->getLibraryTreeModel();
-        pLibraryTreeModel->showModelWidget(mpDocumentationHistoryList->at(mDocumentationHistoryPos).mpLibraryTreeItem);
-      } else {
-        mpEditInfoAction->setDisabled(true);
-        mpEditRevisionsAction->setDisabled(true);
-        mpEditInfoHeaderAction->setDisabled(true);
-        mpSaveAction->setDisabled(true);
-        mpCancelAction->setDisabled(true);
-        mpDocumentationViewer->setHtml(""); // clear if we don't have any documentation to show
-        mpDocumentationViewerFrame->show();
-        mpEditorsWidget->hide();
-        mEditType = EditType::None;
-      }
     }
-  }
+  } while (index > -1);
+
+  return removed;
 }
 
 /*!
@@ -786,7 +806,7 @@ void DocumentationWidget::editInfoDocumentation()
 {
   if (mDocumentationHistoryPos >= 0) {
     LibraryTreeItem *pLibraryTreeItem = mpDocumentationHistoryList->at(mDocumentationHistoryPos).mpLibraryTreeItem;
-    if (pLibraryTreeItem && !pLibraryTreeItem->isNonExisting()) {
+    if (pLibraryTreeItem) {
       // get the info documentation
       QList<QString> info = MainWindow::instance()->getOMCProxy()->getDocumentationAnnotationInClass(pLibraryTreeItem);
       writeDocumentationFile(info.at(0));
@@ -821,7 +841,7 @@ void DocumentationWidget::editRevisionsDocumentation()
 {
   if (mDocumentationHistoryPos >= 0) {
     LibraryTreeItem *pLibraryTreeItem = mpDocumentationHistoryList->at(mDocumentationHistoryPos).mpLibraryTreeItem;
-    if (pLibraryTreeItem && !pLibraryTreeItem->isNonExisting()) {
+    if (pLibraryTreeItem) {
       // get the revision documentation
       QList<QString> revisions = MainWindow::instance()->getOMCProxy()->getDocumentationAnnotationInClass(pLibraryTreeItem);
       writeDocumentationFile(revisions.at(1));
@@ -856,7 +876,7 @@ void DocumentationWidget::editInfoHeaderDocumentation()
 {
   if (mDocumentationHistoryPos >= 0) {
     LibraryTreeItem *pLibraryTreeItem = mpDocumentationHistoryList->at(mDocumentationHistoryPos).mpLibraryTreeItem;
-    if (pLibraryTreeItem && !pLibraryTreeItem->isNonExisting()) {
+    if (pLibraryTreeItem) {
       // get the __OpenModelica_infoHeader documentation annotation
       QList<QString> infoHeader = MainWindow::instance()->getOMCProxy()->getDocumentationAnnotationInClass(pLibraryTreeItem);
       writeDocumentationFile(infoHeader.at(2));
@@ -893,7 +913,7 @@ void DocumentationWidget::saveDocumentation(LibraryTreeItem *pNextLibraryTreeIte
 {
   if (mDocumentationHistoryPos >= 0) {
     LibraryTreeItem *pLibraryTreeItem = mpDocumentationHistoryList->at(mDocumentationHistoryPos).mpLibraryTreeItem;
-    if (pLibraryTreeItem && !pLibraryTreeItem->isNonExisting()) {
+    if (pLibraryTreeItem) {
       QList<QString> documentation = MainWindow::instance()->getOMCProxy()->getDocumentationAnnotationInClass(pLibraryTreeItem);
       // old documentation annotation
       QList<QString> oldDocAnnotationList;
@@ -1021,6 +1041,14 @@ void DocumentationWidget::updateActions()
   QString fontName = queryCommandValue("fontName");
   // font name has extra single quote around it so remove it.
   fontName = StringHandler::removeFirstLastSingleQuotes(fontName);
+  /* Issue #13038
+   * We get the current font name by calling `document.queryCommandValue("fontName")` via JavaScript on current cursor position.
+   * The webkit returns `-webkit-standard` for default font name instead of the actual font name.
+   * When we get `-webkit-standard` convert it to default system font name.
+   */
+  if (fontName.compare(QStringLiteral("-webkit-standard")) == 0) {
+    fontName = Helper::systemFontInfo.family();
+  }
   currentIndex = mpFontComboBox->findText(fontName, Qt::MatchExactly);
   if (currentIndex > -1) {
     mpFontComboBox->setCurrentIndex(currentIndex);
@@ -1242,15 +1270,6 @@ void DocumentationWidget::updateHTMLSourceEditor()
   mpHTMLSourceEditor->getPlainTextEdit()->setPlainText(mpHTMLEditor->page()->mainFrame()->toHtml());
 #endif
 }
-
-/*!
- * \brief DocumentationWidget::updateDocumentationHistory
- * Slot activated when LibraryTreeItem unloaded SIGNAL is raised.
- */
-void DocumentationWidget::updateDocumentationHistory()
-{
-  updateDocumentationHistory(qobject_cast<LibraryTreeItem*>(sender()));
-}
 #endif // #ifndef OM_DISABLE_DOCUMENTATION
 
 /*!
@@ -1319,8 +1338,8 @@ void DocumentationViewer::setFocusInternal()
 {
   setFocus(Qt::ActiveWindowFocusReason);
   QPoint center = QPoint(0, 0);
-  QMouseEvent *pMouseEvent1 = new QMouseEvent(QEvent::MouseButtonPress, center, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
-  QMouseEvent *pMouseEvent2 = new QMouseEvent(QEvent::MouseButtonRelease, center, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+  QMouseEvent *pMouseEvent1 = new QMouseEvent(QEvent::MouseButtonPress, center, center, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+  QMouseEvent *pMouseEvent2 = new QMouseEvent(QEvent::MouseButtonRelease, center, center, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
   QApplication::postEvent(this, pMouseEvent1);
   QApplication::postEvent(this, pMouseEvent2);
 }
@@ -1552,7 +1571,7 @@ void DocumentationViewer::keyPressEvent(QKeyEvent *event)
  */
 void DocumentationViewer::wheelEvent(QWheelEvent *event)
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
   if (event->angleDelta().y() != 0 && event->modifiers().testFlag(Qt::ControlModifier)) {
 #else // QT_VERSION_CHECK
   if (event->orientation() == Qt::Vertical && event->modifiers().testFlag(Qt::ControlModifier)) {
@@ -1561,7 +1580,7 @@ void DocumentationViewer::wheelEvent(QWheelEvent *event)
     /* ticket:4349 Take smaller steps for zooming.
      * Also set the minimum zoom to readable size.
      */
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
   if (event->angleDelta().y() > 0) {
 #else // QT_VERSION_CHECK
   if (event->delta() > 0) {
