@@ -41,6 +41,7 @@
 #include "OMS/OMSProxy.h"
 
 #include <QTreeView>
+#include <QRegExp>
 #include <QSortFilterProxyModel>
 
 class CompleterItem;
@@ -57,8 +58,8 @@ public:
   enum LibraryType {
     Modelica,         /* Used to represent Modelica models. */
     Text,             /* Used to represent text based files. */
-    CompositeModel,   /* Used to represent CompositeModel files. */
-    OMS               /* Used to represent OMSimulator models. */
+    OMS,              /* Used to represent OMSimulator models. */
+    CRML              /* Used to represent CRML models. */
   };
   enum Access {
     hide,
@@ -84,6 +85,10 @@ public:
   QList<LibraryTreeItem*> childrenItems() {return mChildren;}
   LibraryType getLibraryType() {return mLibraryType;}
   void setLibraryType(LibraryType libraryType) {mLibraryType = libraryType;}
+  bool isModelica() const {return mLibraryType == LibraryTreeItem::Modelica;}
+  bool isText() const {return mLibraryType == LibraryTreeItem::Text;}
+  bool isCRML() const {return mLibraryType == LibraryTreeItem::CRML;}
+  bool isSSP() const {return mLibraryType == LibraryTreeItem::OMS;}
   void setSystemLibrary(bool systemLibrary) {mSystemLibrary = systemLibrary;}
   bool isSystemLibrary() {return mSystemLibrary;}
   void setModelWidget(ModelWidget *pModelWidget);
@@ -101,6 +106,8 @@ public:
   const QString& getVersionBuild() const;
   const QString& getDateModified() const;
   const QString& getRevisionId() const;
+  bool isCRMLFile() const;
+  bool isMOSFile() const {return mFileName.endsWith(".mos");}
   bool isFilePathValid();
   void setReadOnly(bool readOnly) {mReadOnly = readOnly;}
   bool isReadOnly() {return mReadOnly;}
@@ -111,10 +118,11 @@ public:
   StringHandler::ModelicaClasses getRestriction() const {return StringHandler::getModelicaClassType(mClassInformation.restriction);}
   bool isConnector() {return (getRestriction() == StringHandler::ExpandableConnector || getRestriction() == StringHandler::Connector);}
   bool isPartial() {return mClassInformation.partialPrefix;}
-  bool isState() {return mClassInformation.state;}
   Access getAccess();
   void setSaveContentsType(LibraryTreeItem::SaveContentsType saveContentsType) {mSaveContentsType = saveContentsType;}
   SaveContentsType getSaveContentsType() {return mSaveContentsType;}
+  bool isSaveInOneFile() const {return mSaveContentsType == LibraryTreeItem::SaveInOneFile;}
+  bool isSaveFolderStructure() const {return mSaveContentsType == LibraryTreeItem::SaveFolderStructure;}
   void setPixmap(QPixmap pixmap) {mPixmap = pixmap;}
   QPixmap getPixmap() {return mPixmap;}
   void setDragPixmap(QPixmap dragPixmap) {mDragPixmap = dragPixmap;}
@@ -127,9 +135,9 @@ public:
   QString getClassTextAfter() {return mClassTextAfter;}
   void setExpanded(bool expanded) {mExpanded = expanded;}
   bool isExpanded() const {return mExpanded;}
-  void setNonExisting(bool nonExisting) {mNonExisting = nonExisting;}
-  bool isNonExisting() const {return mNonExisting;}
   bool isEncryptedClass() const {return mFileName.endsWith(".moc");}
+  bool isInternal() const {return mInternal;}
+  void setInternal(bool internal) {mInternal = internal;}
   bool isAccessAnnotationsEnabled() const {return mAccessAnnotations;}
   void setAccessAnnotations(bool accessAnnotations) {mAccessAnnotations = accessAnnotations;}
   void setOMSElement(oms_element_t *pOMSComponent) {mpOMSElement = pOMSComponent;}
@@ -167,8 +175,6 @@ public:
   void insertChild(int position, LibraryTreeItem *pLibraryTreeItem);
   LibraryTreeItem* child(int row);
   void moveChild(int from, int to);
-  void addInheritedClass(LibraryTreeItem *pLibraryTreeItem);
-  void removeInheritedClasses();
   const QList<LibraryTreeItem*> &getInheritedClasses();
   QList<LibraryTreeItem*> getInheritedClassesDeepList();
   LibraryTreeItem *getDirectComponentsClass(const QString &name);
@@ -181,27 +187,19 @@ public:
   LibraryTreeItem* parent() const {return mpParentLibraryTreeItem;}
   bool isTopLevel() const;
   bool isSimulationAllowed();
-  void emitLoaded();
-  void emitUnLoaded();
-  void emitShapeAdded(ShapeAnnotation *pShapeAnnotation, GraphicsView *pGraphicsView);
-  void emitComponentAdded(Element *pComponent);
-  void emitComponentAddedForComponent() {emit componentAddedForComponent();}
-  void emitNameChanged() {emit nameChanged();}
   void updateChildrenNameStructure();
-  void emitConnectionAdded(LineAnnotation *pConnectionLineAnnotation) {emit connectionAdded(pConnectionLineAnnotation);}
-  void emitCoOrdinateSystemUpdated(GraphicsView *pGraphicsView);
   QString getHTMLDescription() const;
 
   OMCInterface::getClassInformation_res mClassInformation;
   SimulationOptions mSimulationOptions;
-  const QList<ElementInfo*> &getComponentsList();
+  const QList<ElementInfo> &getComponentsList();
 private:
   bool mIsRootItem;
   LibraryTreeItem *mpParentLibraryTreeItem = 0;
   QList<LibraryTreeItem*> mChildren;
   bool mInheritedClassesLoaded = false;
   QList<LibraryTreeItem*> mInheritedClasses;
-  QList<ElementInfo*> mComponents;
+  QList<ElementInfo> mComponents;
   bool mComponentsLoaded = false;
   LibraryType mLibraryType = LibraryTreeItem::Modelica;
   bool mSystemLibrary = false;
@@ -223,7 +221,7 @@ private:
   QString mClassText;
   QString mClassTextAfter;
   bool mExpanded = false;
-  bool mNonExisting = false;
+  bool mInternal = false;
   bool mAccessAnnotations = false;
   oms_element_t *mpOMSElement = 0;
   oms_system_enu_t mSystemType = oms_system_none;
@@ -235,27 +233,9 @@ private:
   const oms_external_tlm_model_info_t *mpExternalTLMModelInfo = 0;
   QString mSubModelPath;
 signals:
-  void loaded(LibraryTreeItem *pLibraryTreeItem);
-  void loadedForComponent();
-  void unLoaded();
-  void unLoadedForComponent();
-  void shapeAdded(ShapeAnnotation *pShapeAnnotation, GraphicsView *pGraphicsView);
-  void shapeAddedForComponent();
-  void componentAdded(Element *pComponent);
-  void componentAddedForComponent();
-  void nameChanged();
-  void connectionAdded(LineAnnotation *pConnectionLineAnnotation);
   void iconUpdated();
-  void coOrdinateSystemUpdated(GraphicsView *pGraphicsView);
-  void coOrdinateSystemUpdatedForComponent();
 public slots:
-  void handleLoaded(LibraryTreeItem *pLibraryTreeItem);
-  void handleUnloaded();
-  void handleShapeAdded(ShapeAnnotation *pShapeAnnotation, GraphicsView *pGraphicsView);
-  void handleComponentAdded(Element *pComponent);
-  void handleConnectionAdded(LineAnnotation *pConnectionLineAnnotation);
   void handleIconUpdated();
-  void handleCoOrdinateSystemUpdated(GraphicsView *pGraphicsView);
 };
 
 class LibraryWidget;
@@ -287,24 +267,21 @@ public:
   LibraryTreeItem* findLibraryTreeItem(const QString &name, LibraryTreeItem *pLibraryTreeItem = 0,
                                        Qt::CaseSensitivity caseSensitivity = Qt::CaseSensitive) const;
   LibraryTreeItem* findLibraryTreeItem(const QRegExp &regExp, LibraryTreeItem *pLibraryTreeItem = 0) const;
-  LibraryTreeItem* findLibraryTreeItemOneLevel(const QString &name, LibraryTreeItem *pLibraryTreeItem = 0,
-                                               Qt::CaseSensitivity caseSensitivity = Qt::CaseSensitive) const;
-  LibraryTreeItem* findNonExistingLibraryTreeItem(const QString &name, Qt::CaseSensitivity caseSensitivity = Qt::CaseSensitive) const;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+  LibraryTreeItem* findLibraryTreeItem(const QRegularExpression &regExp, LibraryTreeItem *pLibraryTreeItem = 0) const;
+#endif
+  LibraryTreeItem* findLibraryTreeItemOneLevel(const QString &name, LibraryTreeItem *pLibraryTreeItem = 0, Qt::CaseSensitivity caseSensitivity = Qt::CaseSensitive) const;
   QModelIndex libraryTreeItemIndex(const LibraryTreeItem *pLibraryTreeItem) const;
   void addModelicaLibraries(const QVector<QPair<QString, QString> > libraries = QVector<QPair<QString, QString> >());
   LibraryTreeItem* createLibraryTreeItem(QString name, LibraryTreeItem *pParentLibraryTreeItem, bool isSaved = true,
                                          bool isSystemLibrary = false, bool load = false, int row = -1, bool loadingMOL = false);
-  LibraryTreeItem* createNonExistingLibraryTreeItem(QString nameStructure);
   void createLibraryTreeItems(QFileInfo fileInfo, LibraryTreeItem *pParentLibraryTreeItem);
   LibraryTreeItem* createLibraryTreeItem(LibraryTreeItem::LibraryType type, QString name, QString nameStructure, QString path, bool isSaved,
                                          LibraryTreeItem *pParentLibraryTreeItem, int row = -1);
-  LibraryTreeItem* createLibraryTreeItem(QString name, QString nameStructure, QString path, bool isSaved,
+  LibraryTreeItem* createLibraryTreeItem(QString name, QString nameStructursre, QString path, bool isSaved,
                                          LibraryTreeItem *pParentLibraryTreeItem, oms_element_t *pOMSElement = 0,
                                          oms_connector_t *pOMSConnector = 0, oms_busconnector_t *pOMSBusConnector = 0,
                                          oms_tlmbusconnector_t *pOMSTLMBusConnector = 0, int row = -1);
-  void checkIfAnyNonExistingClassLoaded();
-  void addNonExistingLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem) {mNonExistingLibraryTreeItemsList.append(pLibraryTreeItem);}
-  void removeNonExistingLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem) {mNonExistingLibraryTreeItemsList.removeOne(pLibraryTreeItem);}
   void updateLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   void updateLibraryTreeItemClassText(LibraryTreeItem *pLibraryTreeItem);
   void updateChildLibraryTreeItemClassText(LibraryTreeItem *pLibraryTreeItem, QString contents, QString fileName);
@@ -317,7 +294,8 @@ public:
   void showModelWidget(LibraryTreeItem *pLibraryTreeItem, bool show = true);
   void showHideProtectedClasses();
   bool unloadClass(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true, bool doDeleteClass = true);
-  bool unloadCompositeModelOrTextFile(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true);
+  bool reloadClass(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true);
+  bool unloadTextFile(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true);
   bool unloadOMSModel(LibraryTreeItem *pLibraryTreeItem, bool doDelete = true, bool askQuestion = true);
   void getExpandedLibraryTreeItemsList(LibraryTreeItem *pLibraryTreeItem, QStringList *pExpandedLibraryTreeItemsList);
   void expandLibraryTreeItems(LibraryTreeItem *pLibraryTreeItem, QStringList expandedLibraryTreeItemsList);
@@ -339,7 +317,6 @@ public:
 private:
   LibraryWidget *mpLibraryWidget;
   LibraryTreeItem *mpRootLibraryTreeItem;
-  QList<LibraryTreeItem*> mNonExistingLibraryTreeItemsList;
   bool mCreatingAutoLoadedLibrary = false;
 
   QModelIndex libraryTreeItemIndexHelper(const LibraryTreeItem *pLibraryTreeItem, const LibraryTreeItem *pParentLibraryTreeItem, const QModelIndex &parentIndex) const;
@@ -348,7 +325,6 @@ private:
   QString readLibraryTreeItemClassTextFromFile(LibraryTreeItem *pLibraryTreeItem);
   LibraryTreeItem* createLibraryTreeItemImpl(QString name, LibraryTreeItem *pParentLibraryTreeItem, bool isSaved = true,
                                              bool isSystemLibrary = false, bool load = false, int row = -1, bool activateAccessAnnotations = false);
-  void createNonExistingLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, LibraryTreeItem *pParentLibraryTreeItem, bool isSaved = true, int row = -1);
   void createLibraryTreeItemsImpl(QFileInfo fileInfo, LibraryTreeItem *pParentLibraryTreeItem);
   LibraryTreeItem* createLibraryTreeItemImpl(LibraryTreeItem::LibraryType type, QString name, QString nameStructure, QString path, bool isSaved,
                                              LibraryTreeItem *pParentLibraryTreeItem, int row = -1);
@@ -397,13 +373,17 @@ private:
   QAction *mpCallFunctionAction;
   QAction *mpSimulateWithTransformationalDebuggerAction;
   QAction *mpSimulateWithAlgorithmicDebuggerAction;
+  QAction *mpTranslateCRMLAction;
+  QAction *mpTranslateAsCRMLAction;
+  QAction *mpRunScriptAction;
 #if !defined(WITHOUT_OSG)
   QAction *mpSimulateWithAnimationAction;
 #endif
   QAction *mpSimulationSetupAction;
   QAction *mpDuplicateClassAction;
   QAction *mpUnloadClassAction;
-  QAction *mpUnloadCompositeModelFileAction;
+  QAction *mpReloadClassAction;
+  QAction *mpUnloadTextFileAction;
   QAction *mpNewFileAction;
   QAction *mpNewFileEmptyAction;
   QAction *mpNewFolderAction;
@@ -418,8 +398,6 @@ private:
   QAction *mpExportFigaroAction;
   QAction *mpUpdateBindingsAction;
   QAction *mpGenerateVerificationScenariosAction;
-  QAction *mpFetchInterfaceDataAction;
-  QAction *mpTLMCoSimulationAction;
   QAction *mpOMSRenameAction;
   QAction *mpUnloadOMSModelAction;
   void createActions();
@@ -450,9 +428,13 @@ public slots:
   void simulateWithAlgorithmicDebugger();
   void simulateWithAnimation();
   void simulationSetup();
+  void translateCRML();
+  void translateAsCRML();
+  void runScript();
   void duplicateClass();
   void unloadClass();
-  void unloadCompositeModelOrTextFile();
+  void reloadClass();
+  void unloadTextFile();
   void createNewFile();
   void createNewFileEmpty();
   void createNewFolder();
@@ -467,8 +449,6 @@ public slots:
   void exportModelFigaro();
   void updateBindings();
   void generateVerificationScenarios();
-  void fetchInterfaceData();
-  void TLMSimulate();
   void OMSRename();
   void unloadOMSModel();
 protected:
@@ -485,14 +465,13 @@ public:
   LibraryTreeModel* getLibraryTreeModel() {return mpLibraryTreeModel;}
   LibraryTreeProxyModel* getLibraryTreeProxyModel() {return mpLibraryTreeProxyModel;}
   LibraryTreeView* getLibraryTreeView() {return mpLibraryTreeView;}
-  void openFile(QString fileName, QString encoding = Helper::utf8, bool showProgress = true, bool checkFileExists = false,
-                bool loadExternalModel = false);
-  void openModelicaFile(QString fileName, QString encoding = Helper::utf8, bool showProgress = true, bool secondAttempt = false);
-  void openEncrytpedModelicaLibrary(QString fileName, QString encoding = Helper::utf8, bool showProgress = true);
-  void openCompositeModelOrTextFile(QFileInfo fileInfo, bool showProgress = true);
+  void openFile(QString fileName, QString encoding = Helper::utf8, bool showProgress = true, bool checkFileExists = false, bool loadExternalModel = false);
+  void openModelicaFile(QString fileName, QString encoding = Helper::utf8, bool showProgress = true, bool secondAttempt = false, int row = -1);
+  void openEncryptedModelicaLibrary(QString fileName, QString encoding = Helper::utf8, bool showProgress = true);
+  void openTextFile(QFileInfo fileInfo, bool showProgress = true);
+
   void openDirectory(QFileInfo fileInfo, bool showProgress = true);
   void openOMSModelFile(QFileInfo fileInfo, bool showProgress = true);
-  bool parseCompositeModelFile(QFileInfo fileInfo, QString *pCompositeModelName);
   void parseAndLoadModelicaText(QString modelText);
   bool saveFile(QString fileName, QString contents);
   bool saveLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
@@ -520,10 +499,7 @@ private:
   bool saveTextLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, bool saveAs);
   bool saveOMSLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   void saveOMSLibraryTreeItemHelper(LibraryTreeItem *pLibraryTreeItem, QString fileName);
-  bool saveCompositeModelLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
-  bool saveAsCompositeModelLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   bool saveAsOMSLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
-  bool saveCompositeModelLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, QString fileName);
   void saveTotalLibraryTreeItemHelper(LibraryTreeItem *pLibraryTreeItem);
   bool resolveConflictWithLoadedLibraries(const QString &library, const QStringList classes);
   static void cancelLoadingLibraries(const QStringList classes);
