@@ -36,6 +36,8 @@
 #include "Util/Helper.h"
 #include "MessagesWidget.h"
 #include "Options/OptionsDialog.h"
+#include "MainWindow.h"
+#include "OMC/OMCProxy.h"
 
 #include <QRectF>
 #include <QtMath>
@@ -59,18 +61,18 @@ namespace ModelInstance
 
   /*!
    * \brief CoordinateSystem::CoordinateSystem
-   * \param coOrdinateSystem
+   * \param CoordinateSystem
    */
-  CoordinateSystem::CoordinateSystem(const CoordinateSystem &coOrdinateSystem)
+  CoordinateSystem::CoordinateSystem(const CoordinateSystem &coordinateSystem)
   {
-    setExtent(coOrdinateSystem.getExtent());
-    setHasExtent(coOrdinateSystem.hasExtent());
-    setPreserveAspectRatio(coOrdinateSystem.getPreserveAspectRatio());
-    setHasPreserveAspectRatio(coOrdinateSystem.hasPreserveAspectRatio());
-    setInitialScale(coOrdinateSystem.getInitialScale());
-    setHasInitialScale(coOrdinateSystem.hasInitialScale());
-    setGrid(coOrdinateSystem.getGrid());
-    setHasGrid(coOrdinateSystem.hasGrid());
+    setExtent(coordinateSystem.getExtent());
+    setHasExtent(coordinateSystem.hasExtent());
+    setPreserveAspectRatio(coordinateSystem.getPreserveAspectRatio());
+    setHasPreserveAspectRatio(coordinateSystem.hasPreserveAspectRatio());
+    setInitialScale(coordinateSystem.getInitialScale());
+    setHasInitialScale(coordinateSystem.hasInitialScale());
+    setGrid(coordinateSystem.getGrid());
+    setHasGrid(coordinateSystem.hasGrid());
   }
 
   void CoordinateSystem::setExtent(const QVector<QPointF> extent)
@@ -490,6 +492,30 @@ namespace ModelInstance
     }
   }
 
+  void IconDiagramMap::deserialize(const QJsonObject &jsonObject)
+  {
+    if (jsonObject.contains("extent")) {
+      mHasExtent = true;
+      mExtent.deserialize(jsonObject.value("extent"));
+    }
+
+    if (jsonObject.contains("primitivesVisible")) {
+      mPrimitivesVisible.deserialize(jsonObject.value("primitivesVisible"));
+    }
+  }
+
+  void ExperimentAnnotation::deserialize(const QJsonObject &jsonObject)
+  {
+    /* We only use this to check if the model has Interval defined in experiment annotation.
+     * The simulation still uses getSimulationOptions() API.
+     * We might change this in future.
+     */
+    if (jsonObject.contains("Interval")) {
+      mHasInterval = true;
+      //mInterval.deserialize(jsonObject.value("extent"));
+    }
+  }
+
   Annotation Annotation::defaultAnnotation{nullptr};
 
   Annotation::Annotation(Model *pParentModel)
@@ -606,6 +632,10 @@ namespace ModelInstance
     if (jsonObject.contains("DiagramMap")) {
       mDiagramMap.deserialize(jsonObject.value("DiagramMap").toObject());
     }
+    // experiment annotation
+    if (jsonObject.contains("experiment")) {
+      mExperimentAnnotation.deserialize(jsonObject.value("experiment").toObject());
+    }
   }
 
   /*!
@@ -637,7 +667,7 @@ namespace ModelInstance
   {
     if (jsonObject.contains("coordinateSystem")) {
       mCoordinateSystem.deserialize(jsonObject.value("coordinateSystem").toObject());
-      mMergedCoOrdinateSystem = mCoordinateSystem;
+      mMergedCoordinateSystem = mCoordinateSystem;
     }
 
     if (jsonObject.contains("graphics")) {
@@ -689,15 +719,13 @@ namespace ModelInstance
   void Dimensions::deserialize(const QJsonObject &jsonObject)
   {
     if (jsonObject.contains("absyn")) {
-      QJsonArray absynDimsArray = jsonObject.value("absyn").toArray();
-      foreach (auto absynDim, absynDimsArray) {
+      for (const QJsonValue &absynDim: jsonObject.value("absyn").toArray()) {
         mAbsynDims.append(absynDim.toString());
       }
     }
 
     if (jsonObject.contains("typed")) {
-      QJsonArray typedDimsArray = jsonObject.value("typed").toArray();
-      foreach (auto typedDim, typedDimsArray) {
+      for (const QJsonValue &typedDim: jsonObject.value("typed").toArray()) {
         mTypedDims.append(typedDim.toString());
       }
     }
@@ -816,6 +844,38 @@ namespace ModelInstance
     return pModifier && pModifier->getName().compare(modifier) == 0;
   }
 
+  /*!
+   * \brief createModifier
+   * Creates the Modifier from another Modifier.\n
+   * See issue #13301 and #13516.\n
+   * Dump the modifier as string and use OMCProxy::modifierToJSON to convert it to JSON.\n
+   * Contruct new Modifier instance with JSON.
+   * \param pModifier
+   * \return
+   */
+  Modifier *createModifier(const Modifier *pModifier, Model *pParentModel)
+  {
+    // If value is defined then we wrap within parenthesis otherwise its not needed.
+    if (pModifier->isValueDefined()) {
+      QJsonObject jsonObject = MainWindow::instance()->getOMCProxy()->modifierToJSON("(" % pModifier->toString() % ")");
+      return new Modifier(pModifier->getName(), jsonObject.value(pModifier->getName()), pParentModel);
+    } else {
+      QJsonObject jsonObject;
+      jsonObject.insert("modifiers", MainWindow::instance()->getOMCProxy()->modifierToJSON(pModifier->toString()));
+      return new Modifier(pModifier->getName(), jsonObject.value("modifiers"), pParentModel);
+    }
+  }
+
+  void Modifier::addModifier(const Modifier *pModifier)
+  {
+    mModifiers.append(createModifier(pModifier, mpParentModel));
+  }
+
+  bool Modifier::isBreak() const
+  {
+    return mValue.compare(Helper::BREAK) == 0 ? true : false;
+  }
+
   bool Modifier::isRedeclare() const
   {
     return mpElement && mpElement->isRedeclare();
@@ -968,12 +1028,22 @@ namespace ModelInstance
   {
     QStringList value;
 
-    if (mRedeclare) {
-      value.append("redeclare");
-    }
     if (mFinal && !skipTopLevel) {
       value.append("final");
     }
+
+    if (mRedeclare) {
+      value.append("redeclare");
+    }
+
+    if (mInner) {
+      value.append("inner");
+    }
+
+    if (mOuter) {
+      value.append("outer");
+    }
+
     if (mpReplaceable) {
       value.append("replaceable");
     }
@@ -1042,6 +1112,8 @@ namespace ModelInstance
     qDeleteAll(mElements);
     mElements.clear();
 
+    mImports.clear();
+
     qDeleteAll(mConnections);
     mConnections.clear();
 
@@ -1085,26 +1157,19 @@ namespace ModelInstance
       mpAnnotation->deserialize(mModelJson.value("annotation").toObject());
     }
 
-    /* From Modelica Specification Version 3.5-dev
-     * The coordinate system (including preserveAspectRatio) of a class is defined by the following priority:
-     * 1. The coordinate system annotation given in the class (if specified).
-     * 2. The coordinate systems of the first base-class where the extent on the extends-clause specifies a
-     *    null-region (if any). Note that null-region is the default for base-classes, see section 18.6.3.
-     * 3. The default coordinate system CoordinateSystem(extent={{-100, -100}, {100, 100}}).
-     *
-     * Following is the second case. First case is covered when we read the annotation of the class. Third case is handled by default values of IconDiagramAnnotation class.
-     */
-    if (!getAnnotation()->getIconAnnotation()->mMergedCoOrdinateSystem.isComplete()) {
-      readCoordinateSystemFromExtendsClass(&getAnnotation()->getIconAnnotation()->mMergedCoOrdinateSystem, true);
-    }
+    updateMergedCoordinateSystem();
 
-    if (!getAnnotation()->getDiagramAnnotation()->mMergedCoOrdinateSystem.isComplete()) {
-      readCoordinateSystemFromExtendsClass(&getAnnotation()->getDiagramAnnotation()->mMergedCoOrdinateSystem, false);
+    if (mModelJson.contains("imports")) {
+      for (const QJsonValue &import: mModelJson.value("imports").toArray()) {
+        QJsonObject importObject = import.toObject();
+        if (!importObject.isEmpty()) {
+          mImports.append(Import(importObject));
+        }
+      }
     }
 
     if (mModelJson.contains("connections")) {
-      QJsonArray connections = mModelJson.value("connections").toArray();
-      foreach (QJsonValue connection, connections) {
+      for (const QJsonValue &connection: mModelJson.value("connections").toArray()) {
         QJsonObject connectionObject = connection.toObject();
         if (!connectionObject.isEmpty()) {
           Connection *pConnection = new Connection(this);
@@ -1115,8 +1180,7 @@ namespace ModelInstance
     }
 
     if (mModelJson.contains("transitions")) {
-      QJsonArray transitions = mModelJson.value("transitions").toArray();
-      foreach (QJsonValue transition, transitions) {
+      for (const QJsonValue &transition: mModelJson.value("transitions").toArray()) {
         QJsonObject transitionObject = transition.toObject();
         if (!transitionObject.isEmpty()) {
           Transition *pTransition = new Transition(this);
@@ -1127,8 +1191,7 @@ namespace ModelInstance
     }
 
     if (mModelJson.contains("initialStates")) {
-      QJsonArray initialStates = mModelJson.value("initialStates").toArray();
-      foreach (QJsonValue initialState, initialStates) {
+      for (const QJsonValue &initialState: mModelJson.value("initialStates").toArray()) {
         QJsonObject initialStateObject = initialState.toObject();
         if (!initialStateObject.isEmpty()) {
           InitialState *pInitialState = new InitialState(this);
@@ -1150,7 +1213,7 @@ namespace ModelInstance
    */
   void Model::deserializeElements(const QJsonArray elements)
   {
-    foreach (const QJsonValue &element, elements) {
+    for (const QJsonValue &element: elements) {
       QJsonObject elementObject = element.toObject();
       QString kind = elementObject.value("$kind").toString();
 
@@ -1166,6 +1229,35 @@ namespace ModelInstance
     }
   }
 
+  void Model::updateMergedCoordinateSystem()
+  {
+    /* From Modelica Specification Version 3.5-dev
+     * The coordinate system (including preserveAspectRatio) of a class is defined by the following priority:
+     * 1. The coordinate system annotation given in the class (if specified).
+     * 2. The coordinate systems of the first base-class where the extent on the extends-clause specifies a
+     *    null-region (if any). Note that null-region is the default for base-classes, see section 18.6.3.
+     * 3. The default coordinate system CoordinateSystem(extent={{-100, -100}, {100, 100}}).
+     *
+     * Following is the second case. First case is covered when we read the annotation of the class. Third case is handled by default values of IconDiagramAnnotation class.
+     */
+    if (!getAnnotation()->getIconAnnotation()->mMergedCoordinateSystem.isComplete()) {
+      readCoordinateSystemFromExtendsClass(&getAnnotation()->getIconAnnotation()->mMergedCoordinateSystem, true);
+    }
+
+    if (!getAnnotation()->getDiagramAnnotation()->mMergedCoordinateSystem.isComplete()) {
+      readCoordinateSystemFromExtendsClass(&getAnnotation()->getDiagramAnnotation()->mMergedCoordinateSystem, false);
+    }
+  }
+
+  Element *Model::getRootParentElement() const
+  {
+    Element *pElement = getParentElement();
+    while (pElement && pElement->getParentModel() && pElement->getParentModel()->getParentElement()) {
+      pElement = pElement->getParentModel()->getParentElement();
+    }
+    return pElement;
+  }
+
   Extend *Model::getParentExtend() const
   {
     if (mpParentElement && mpParentElement->isExtend()) {
@@ -1310,6 +1402,22 @@ namespace ModelInstance
     }
   }
 
+  /*!
+   * \brief Model::removeElement
+   * Removes the element.
+   * \param name
+   */
+  void Model::removeElement(const QString &name)
+  {
+    foreach (auto pElement, mElements) {
+      if (pElement->getName().compare(name) == 0) {
+        mElements.removeOne(pElement);
+        delete pElement;
+        break;
+      }
+    }
+  }
+
   /*!
    * \brief Model::getComponents
    * Returns all components of the model, including inherited ones.
@@ -1378,6 +1486,13 @@ namespace ModelInstance
       return true;
     }
 
+    // Issue #12163. Skip checking for compatibility if any of the component is conditional.
+    const Component *lhs_component = dynamic_cast<const Component*>(lhs);
+    const Component *rhs_component = dynamic_cast<const Component*>(rhs);
+    if ((lhs_component && !lhs_component->getCondition()) || (rhs_component && !rhs_component->getCondition())) {
+      return true;
+    }
+
     Model *lhs_model = lhs->getModel();
     Model *rhs_model = rhs->getModel();
 
@@ -1756,8 +1871,7 @@ namespace ModelInstance
     }
 
     if (jsonObject.contains("choice")) {
-      QJsonArray choices = jsonObject.value("choice").toArray();
-      foreach (auto choice, choices) {
+      for (const auto& choice: jsonObject.value("choice").toArray()) {
         mChoices.append(new Modifier("", choice, mpParentModel));
       }
     }
@@ -2004,8 +2118,9 @@ namespace ModelInstance
     }
   }
 
-  QString Element::toString(bool skipTopLevel) const
+  QString Element::toString(bool skipTopLevel, bool mergeExtendsModifiers) const
   {
+    Q_UNUSED(mergeExtendsModifiers);
     if (mpPrefixes) {
       return mpPrefixes->toString(skipTopLevel);
     }
@@ -2082,15 +2197,25 @@ namespace ModelInstance
 
   /*!
    * \brief Extend::getQualifiedName
-   * Returns the qualified name of component.
+   * Returns the qualified name of extend.
+   * \param includeBaseName
    * \return
    */
-  QString Extend::getQualifiedName() const
+  QString Extend::getQualifiedName(bool includeBaseName) const
   {
     if (mpParentModel && mpParentModel->getParentElement()) {
-      return mpParentModel->getParentElement()->getQualifiedName();
+      if (includeBaseName) {
+        QString name = mpParentModel->getParentElement()->getQualifiedName(includeBaseName);
+        if (name.isEmpty()) {
+          return mBaseClass;
+        } else {
+          return name % "." % mBaseClass;
+        }
+      } else {
+        return mpParentModel->getParentElement()->getQualifiedName(includeBaseName);
+      }
     } else {
-      return "";
+      return includeBaseName ? mBaseClass : "";
     }
   }
 
@@ -2102,9 +2227,9 @@ namespace ModelInstance
     return mBaseClass;
   }
 
-  QString Extend::toString(bool skipTopLevel) const
+  QString Extend::toString(bool skipTopLevel, bool mergeExtendsModifiers) const
   {
-    return Element::toString(skipTopLevel);
+    return Element::toString(skipTopLevel, mergeExtendsModifiers);
   }
 
   Component::Component(Model *pParentModel)
@@ -2176,14 +2301,82 @@ namespace ModelInstance
   }
 
   /*!
-   * \brief Component::getQualifiedName
-   * Returns the qualified name of the component.
+   * \brief Component::getExtendsModifiers
+   * Makes a list of all extends modifiers.
+   * \param pParentModel
    * \return
    */
-  QString Component::getQualifiedName() const
+  QList<Modifier*> Component::getExtendsModifiers(const Model *pParentModel) const
+  {
+    QList<Modifier*> modifiers;
+    if (pParentModel && pParentModel->getParentElement() && pParentModel->getParentElement()->getModifier()) {
+      Modifier *pExtentElementModifier = pParentModel->getParentElement()->getModifier();
+      foreach (auto *pSubModifier, pExtentElementModifier->getModifiers()) {
+        if (pSubModifier->getName().compare(mName) == 0) {
+          modifiers.append(pSubModifier);
+        }
+      }
+      modifiers.append(getExtendsModifiers(pExtentElementModifier->getParentModel()));
+    }
+    return modifiers;
+  }
+
+  /*!
+   * \brief Component::mergeModifiersIntoOne
+   * Merges the list of all extends modifiers into one modifier.
+   * \param extendsModifiers
+   * \return
+   */
+  Modifier *Component::mergeModifiersIntoOne(QList<Modifier *> extendsModifiers) const
+  {
+    Modifier *pModifier = nullptr;
+    if (!extendsModifiers.isEmpty()) {
+      pModifier = createModifier(extendsModifiers.last(), mpParentModel);
+      for (int i = extendsModifiers.size() - 2 ; i >= 0 ; i--) {
+        Component::mergeModifiers(pModifier, extendsModifiers.at(i));
+      }
+    }
+    return pModifier;
+  }
+
+  /*!
+   * \brief Component::mergeModifiers
+   * Merges pModifier2 into pModifier1
+   * \param pModifier1
+   * \param pModifier2
+   */
+  void Component::mergeModifiers(Modifier *pModifier1, Modifier *pModifier2)
+  {
+    foreach (auto pSubModifier2, pModifier2->getModifiers()) {
+      bool subModifierFound = false;
+      foreach (auto pSubModifier1, pModifier1->getModifiers()) {
+        /* if modifier exists then check if its value is defined
+         * if the value is not defined then merge sub modifiers
+         */
+        if (pSubModifier2->getName().compare(pSubModifier1->getName()) == 0) {
+          subModifierFound = true;
+          if (!pSubModifier1->isValueDefined()) {
+            Component::mergeModifiers(pSubModifier1, pSubModifier2);
+          }
+        }
+      }
+      // if modifier doesn't exist then add it
+      if (!subModifierFound) {
+        pModifier1->addModifier(pSubModifier2);
+      }
+    }
+  }
+
+  /*!
+   * \brief Component::getQualifiedName
+   * Returns the qualified name of the component.
+   * \param includeBaseName
+   * \return
+   */
+  QString Component::getQualifiedName(bool includeBaseName) const
   {
     if (mpParentModel && mpParentModel->getParentElement()) {
-      QString name = mpParentModel->getParentElement()->getQualifiedName();
+      QString name = mpParentModel->getParentElement()->getQualifiedName(includeBaseName);
       if (name.isEmpty()) {
         return mName;
       } else {
@@ -2202,11 +2395,11 @@ namespace ModelInstance
     return mType;
   }
 
-  QString Component::toString(bool skipTopLevel) const
+  QString Component::toString(bool skipTopLevel, bool mergeExtendsModifiers) const
   {
     QStringList value;
 
-    value.append(Element::toString(skipTopLevel));
+    value.append(Element::toString(skipTopLevel, mergeExtendsModifiers));
 
     if (mpPrefixes) {
       auto prefixes = mpPrefixes->typePrefixes();
@@ -2215,10 +2408,42 @@ namespace ModelInstance
 
     value.append(mType);
     value.append(mName);
-    if (mpModifier) {
+    const QString dims = getDimensions().getAbsynDimensionsString();
+    if (!dims.isEmpty()) {
+      value.append("[" % dims % "]");
+    }
+    // modifiers
+    Modifier *pModifier = nullptr;
+    if (mergeExtendsModifiers) {
+      // Merge extends modifiers. See issue #13301 and #13516.
+      QList<Modifier *> extendsModifiers = getExtendsModifiers(mpParentModel);
+      pModifier = mergeModifiersIntoOne(extendsModifiers);
+    }
+    // if merge modifiers
+    if (pModifier) {
+      // if this modifier exists then merge it
+      if (mpModifier) {
+        Component::mergeModifiers(pModifier, mpModifier);
+      }
+      // we don't need the name coming from the extend modification
+      pModifier->setName("");
+      value.append(pModifier->toString());
+      delete pModifier;
+    } else if (mpModifier) {
+      // if there are no merged modifiers then just use this modifier if exists.
       value.append(mpModifier->toString());
     }
-    if (!mComment.isEmpty()) {
+    // constrainedby issue #13300
+    if (mpPrefixes && mpPrefixes->getReplaceable() && !mpPrefixes->getReplaceable()->getConstrainedby().isEmpty()) {
+      value.append("constrainedby " % mpPrefixes->getReplaceable()->getConstrainedby());
+      if (mpPrefixes->getReplaceable()->getModifier()) {
+        value.append(mpPrefixes->getReplaceable()->getModifier()->toString());
+      }
+    }
+    // comment
+    if (mpPrefixes && mpPrefixes->getReplaceable() && !mpPrefixes->getReplaceable()->getComment().isEmpty()) {
+      value.append("\"" % mpPrefixes->getReplaceable()->getComment() % "\"");
+    } else if (!mComment.isEmpty()) {
       value.append("\"" % mComment % "\"");
     }
 
@@ -2267,10 +2492,16 @@ namespace ModelInstance
     }
   }
 
-  QString ReplaceableClass::getQualifiedName() const
+  /*!
+   * \brief ReplaceableClass::getQualifiedName
+   * Returns the qualified name of the replaceable class.
+   * \param includeBaseName
+   * \return
+   */
+  QString ReplaceableClass::getQualifiedName(bool includeBaseName) const
   {
     if (mpParentModel && mpParentModel->getParentElement()) {
-      QString name = mpParentModel->getParentElement()->getQualifiedName();
+      QString name = mpParentModel->getParentElement()->getQualifiedName(includeBaseName);
       if (name.isEmpty()) {
         return mName;
       } else {
@@ -2281,11 +2512,11 @@ namespace ModelInstance
     }
   }
 
-  QString ReplaceableClass::toString(bool skipTopLevel) const
+  QString ReplaceableClass::toString(bool skipTopLevel, bool mergeExtendsModifiers) const
   {
     QStringList value;
 
-    value.append(Element::toString(skipTopLevel));
+    value.append(Element::toString(skipTopLevel, mergeExtendsModifiers));
     value.append(mType);
     value.append(mName);
     if (!mBaseClass.isEmpty()) {
@@ -2324,7 +2555,7 @@ namespace ModelInstance
     } else {
       mName = str.left(i);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
       for (const auto& sub: QStringView(str).mid(i + 1, str.size() - i - 2).split(',')) {
 #else
       for (const auto& sub: str.midRef(i + 1, str.size() - i - 2).split(',')) {
@@ -2341,8 +2572,7 @@ namespace ModelInstance
     }
 
     if (jsonObject.contains("subscripts")) {
-      QJsonArray subscripts = jsonObject.value("subscripts").toArray();
-      foreach (QJsonValue subscript, subscripts) {
+      for (const QJsonValue &subscript: jsonObject.value("subscripts").toArray()) {
         mSubScripts.append(QString::number(subscript.toInt()));
       }
     }
@@ -2369,7 +2599,7 @@ namespace ModelInstance
 
   void Name::deserialize(const QJsonArray &jsonArray)
   {
-    foreach (QJsonValue part, jsonArray) {
+    for (const QJsonValue &part: jsonArray) {
       Part partObject;
       partObject.deserialize(part.toObject());
       mParts.append(partObject);
@@ -2416,6 +2646,17 @@ namespace ModelInstance
     return mName.getNameParts();
   }
 
+  Import::Import(const QJsonObject &jsonObject)
+  {
+    if (jsonObject.contains("path")) {
+      mPath = jsonObject.value("path").toString();
+    }
+
+    if (jsonObject.contains("shortName")) {
+      mShortName = jsonObject.value("shortName").toString();
+    }
+  }
+
   Connection::Connection(Model *pParentModel)
   {
     mpParentModel = pParentModel;
@@ -2540,16 +2781,4 @@ namespace ModelInstance
     return "initialState(" % mpStartConnector->getName() % ")";
   }
 
-  void IconDiagramMap::deserialize(const QJsonObject &jsonObject)
-  {
-    if (jsonObject.contains("extent")) {
-      mHasExtent = true;
-      mExtent.deserialize(jsonObject.value("extent"));
-    }
-
-    if (jsonObject.contains("primitivesVisible")) {
-      mPrimitivesVisible.deserialize(jsonObject.value("primitivesVisible"));
-    }
-  }
-
 }
