@@ -35,16 +35,16 @@
 #ifndef MODELWIDGETCONTAINER_H
 #define MODELWIDGETCONTAINER_H
 
-#include "CoOrdinateSystem.h"
 #include "Element/Element.h"
 #include "Util/StringHandler.h"
 #include "Util/Helper.h"
 #include "Model.h"
 #include "Editors/BaseEditor.h"
 #include "Editors/ModelicaEditor.h"
-#include "Editors/CompositeModelEditor.h"
 #include "Editors/OMSimulatorEditor.h"
 #include "Editors/CEditor.h"
+#include "Editors/CRMLEditor.h"
+#include "Editors/MOSEditor.h"
 #include "Editors/TextEditor.h"
 #include "Editors/MetaModelicaEditor.h"
 #include "LibraryTreeWidget.h"
@@ -107,12 +107,6 @@ class GraphicsView : public QGraphicsView
 private:
   StringHandler::ViewType mViewType;
   ModelWidget *mpModelWidget;
-  CoOrdinateSystem mCoOrdinateSystem;
-public:
-  CoOrdinateSystem mMergedCoOrdinateSystem;
-  CoOrdinateSystem getCoOrdinateSystem() const {return mCoOrdinateSystem;}
-  void setCoOrdinateSystem(CoOrdinateSystem coOrdinateSystem) {mCoOrdinateSystem = std::move(coOrdinateSystem);}
-private:
   bool mVisualizationView;
   bool mIsCustomScale;
   bool mAddClassAnnotationNeeded;
@@ -158,7 +152,6 @@ private:
   QAction *mpParametersAction;
   QAction *mpPropertiesAction;
   QAction *mpRenameAction;
-  QAction *mpSimulationParamsAction;
   QAction *mpManhattanizeAction;
   QAction *mpDeleteAction;
   QAction *mpBringToFrontAction;
@@ -182,10 +175,15 @@ private:
 public:
   GraphicsView(StringHandler::ViewType viewType, ModelWidget *pModelWidget);
   ~GraphicsView();
+  ModelInstance::CoordinateSystem mCoordinateSystem;
+  ModelInstance::CoordinateSystem mMergedCoordinateSystem;
   bool mSkipBackground; /* Do not draw the background rectangle */
   QPointF mContextMenuStartPosition;
   bool mContextMenuStartPositionValid;
-  StringHandler::ViewType getViewType() {return mViewType;}
+  void initializeCoordinateSystem();
+  void resetCoordinateSystem();
+  bool isIconView() const {return mViewType == StringHandler::Icon;}
+  bool isDiagramView() const {return mViewType == StringHandler::Diagram;}
   ModelWidget* getModelWidget() {return mpModelWidget;}
   void setIsVisualizationView(bool visualizationView);
   bool isVisualizationView() {return mVisualizationView;}
@@ -230,6 +228,7 @@ public:
   void setRenderingLibraryPixmap(bool renderingLibraryPixmap) {mRenderingLibraryPixmap = renderingLibraryPixmap;}
   bool isRenderingLibraryPixmap() {return mRenderingLibraryPixmap;}
   QList<ShapeAnnotation*> getShapesList() {return mShapesList;}
+  void setShapesList(QList<ShapeAnnotation*> shapesList) {mShapesList = shapesList;}
   QList<ShapeAnnotation*> getInheritedShapesList() {return mInheritedShapesList;}
   QAction* getManhattanizeAction() {return mpManhattanizeAction;}
   QAction* getDeleteAction() {return mpDeleteAction;}
@@ -249,9 +248,8 @@ public:
   static ModelInstance::Component* createModelInstanceComponent(ModelInstance::Model *pModelInstance, const QString &name, const QString &className);
   static ModelInstance::Component* createModelInstanceComponent(ModelInstance::Model *pModelInstance, const QString &name, const QString &className, bool isConnector);
   bool addComponent(QString className, QPointF position);
-  void addComponentToView(QString name, LibraryTreeItem *pLibraryTreeItem, QString annotation, QPointF position,
-                          ElementInfo *pComponentInfo, bool addObject, bool openingClass, bool emitComponentAdded);
-  void addElementToView(ModelInstance::Component *pComponent, bool inherited, bool addElementToOMC, bool createTransformation, QPointF position, const QString &placementAnnotation, bool clearSelection);
+  void addElementToView(ModelInstance::Component *pComponent, bool inherited, bool addElementToOMC, bool createTransformation, QPointF position,
+                        const QString &placementAnnotation, bool clearSelection);
   void addElementToList(Element *pElement) {mElementsList.append(pElement);}
   void addElementToOutOfSceneList(Element *pElement) {mOutOfSceneElementsList.append(pElement);}
   void addInheritedElementToList(Element *pElement) {mInheritedElementsList.append(pElement);}
@@ -265,6 +263,7 @@ public:
   void deleteElementFromOutOfSceneList(Element *pElement) {mOutOfSceneElementsList.removeOne(pElement);}
   void deleteInheritedElementFromList(Element *pElement) {mInheritedElementsList.removeOne(pElement);}
   Element* getElementObject(QString elementName);
+  Element* getElementObjectFromQualifiedName(QString elementQualifiedName);
   QString getUniqueElementName(const QString &nameStructure, const QString &name, QString *defaultName);
   QString getUniqueElementName(const QString &nameStructure, QString elementName, int number = 0);
   bool checkElementName(const QString &nameStructure, QString elementName);
@@ -276,14 +275,12 @@ public:
   void addConnectionToView(LineAnnotation *pConnectionLineAnnotation, bool inherited);
   bool addConnectionToClass(LineAnnotation *pConnectionLineAnnotation, bool deleteUndo = false);
   void deleteConnectionFromClass(LineAnnotation *pConnectionLineAnnotation);
-  void updateConnectionInClass(LineAnnotation *pConnectionLineAnnotation);
   void addConnectionToList(LineAnnotation *pConnectionLineAnnotation) {mConnectionsList.append(pConnectionLineAnnotation);}
   void addConnectionToOutOfSceneList(LineAnnotation *pConnectionLineAnnotation) {mOutOfSceneConnectionsList.append(pConnectionLineAnnotation);}
   void addInheritedConnectionToList(LineAnnotation *pConnectionLineAnnotation) {mInheritedConnectionsList.append(pConnectionLineAnnotation);}
   void deleteConnectionFromList(LineAnnotation *pConnectionLineAnnotation) {mConnectionsList.removeOne(pConnectionLineAnnotation);}
   void deleteConnectionFromOutOfSceneList(LineAnnotation *pConnectionLineAnnotation) {mOutOfSceneConnectionsList.removeOne(pConnectionLineAnnotation);}
   void removeConnectionDetails(LineAnnotation *pConnectionLineAnnotation);
-  void removeConnectionFromView(LineAnnotation *pConnectionLineAnnotation);
   void removeConnectionsFromView();
   void deleteInheritedConnectionFromList(LineAnnotation *pConnectionLineAnnotation) {mInheritedConnectionsList.removeOne(pConnectionLineAnnotation);}
   int numberOfElementConnections(Element *pElement, LineAnnotation *pExcludeConnectionLineAnnotation = 0);
@@ -325,7 +322,9 @@ public:
   void sendToBack(ShapeAnnotation *pShape);
   void sendBackward(ShapeAnnotation *pShape);
   void clearGraphicsView();
+  void clearGraphicsViewsExceptOutOfSceneItems();
   void removeClassComponents();
+  void removeShapesFromScene();
   void removeElementsFromScene();
   void removeOutOfSceneClassComponents();
   void removeInheritedClassShapes();
@@ -350,7 +349,7 @@ public:
   void createEllipseShape(QPointF point);
   void createTextShape(QPointF point);
   void createBitmapShape(QPointF point);
-  QRectF itemsBoundingRect();
+  QRectF itemsBoundingRect(bool onlySelected = false);
   QPointF snapPointToGrid(QPointF point);
   QPointF movePointByGrid(QPointF point, QPointF origin = QPointF(0, 0), bool useShiftModifier = false);
   QPointF roundPoint(QPointF point);
@@ -392,19 +391,14 @@ private:
   void modelicaOneShapeContextMenu(ShapeAnnotation *pShapeAnnotation, QMenu *pMenu);
   void modelicaOneComponentContextMenu(Element *pComponent, QMenu *pMenu);
   void modelicaMultipleItemsContextMenu(QMenu *pMenu);
-  void compositeModelGraphicsViewContextMenu(QMenu *pMenu);
-  void compositeModelOneShapeContextMenu(ShapeAnnotation *pShapeAnnotation, QMenu *pMenu);
-  void compositeModelOneComponentContextMenu(Element *pComponent, QMenu *pMenu);
-  void compositeModelMultipleItemsContextMenu(QMenu *pMenu);
   void omsGraphicsViewContextMenu(QMenu *pMenu);
   void omsOneShapeContextMenu(ShapeAnnotation *pShapeAnnotation, QMenu *pMenu);
   void omsOneComponentContextMenu(Element *pComponent, QMenu *pMenu);
   void omsMultipleItemsContextMenu(QMenu *pMenu);
-  void getCoOrdinateSystemAndGraphics(QStringList &coOrdinateSystemList, QStringList &graphicsList);
+  void getCoordinateSystemAndGraphics(QStringList &coOrdinateSystemList, QStringList &graphicsList);
 signals:
   void manhattanize();
   void deleteSignal();
-  void duplicate();
   void mouseRotateClockwise();
   void mouseRotateAntiClockwise();
   void mouseFlipHorizontal();
@@ -441,13 +435,12 @@ public slots:
   void selectAll();
   void cutItems();
   void copyItems();
-  void pasteItems();
+  void pasteItems(QPointF positionOffset = QPointF(0, 0));
   void clearSelection(QGraphicsItem *pSelectGraphicsItem = 0);
   void addClassAnnotation();
   void showParameters();
   void showGraphicsViewProperties();
   void showRenameDialog();
-  void showSimulationParamsDialog();
   void manhattanizeItems();
   void deleteItems();
   void duplicateItems();
@@ -529,23 +522,8 @@ private:
   bool mEnabled;
 };
 
-class IconDiagramMap
-{
-public:
-  IconDiagramMap()
-  {
-    mExtent.clear();
-    mExtent << QPointF(0, 0) << QPointF(0, 0);
-    mPrimitivesVisible = true;
-  }
-
-  QVector<QPointF> mExtent;
-  bool mPrimitivesVisible;
-};
-
 class ModelWidgetContainer;
 class ModelicaHighlighter;
-class CompositeModelHighlighter;
 class Label;
 class ModelWidget : public QWidget
 {
@@ -572,49 +550,33 @@ public:
   void setModelFilePathLabel(QString path) {mpModelFilePathLabel->setText(path);}
   QVBoxLayout* getMainLayout() {return mpMainLayout;}
   bool isLoadedWidgetComponents() {return mCreateModelWidgetComponents;}
-  void addInheritedClass(LibraryTreeItem *pLibraryTreeItem) {mInheritedClassesList.append(pLibraryTreeItem);}
-  void removeInheritedClass(LibraryTreeItem *pLibraryTreeItem) {mInheritedClassesList.removeOne(pLibraryTreeItem);}
-  void clearInheritedClasses() {mInheritedClassesList.clear();}
   QList<LibraryTreeItem*> getInheritedClassesList() {return mInheritedClassesList;}
-  QMap<int, IconDiagramMap> getInheritedClassIconMap() {return mInheritedClassesIconMap;}
-  QMap<int, IconDiagramMap> getInheritedClassDiagramMap() {return mInheritedClassesDiagramMap;}
-  const QList<ElementInfo*> &getComponentsList() {return mElementsList;}
-  QMap<QString, QString> getExtendsModifiersMap(QString extendsClass);
-  QMap<QString, QString> getDerivedClassModifiersMap();
 
-  bool isNewApi();
   void addDependsOnModel(const QString &dependsOnModel);
   void clearDependsOnModels() {mDependsOnModelsList.clear();}
   void setHandleCollidingConnectionsNeeded(bool needed) {mHandleCollidingConnectionsNeeded = needed;}
   bool isHandleCollidingConnectionsNeeded() {return mHandleCollidingConnectionsNeeded;}
   void setRequiresUpdate(bool requiresUpdate) {mRequiresUpdate = requiresUpdate;}
   bool requiresUpdate() {return mRequiresUpdate;}
+  bool isElementMode() const {return !mModelInstanceList.isEmpty();}
+  void setComponentModified(bool modified) {mComponentModified = modified;}
+  bool isComponentModified() const {return mComponentModified;}
+  void setRestoringModel(bool restoring) {mRestoringModel = restoring;}
+  bool isRestoringModel() const {return mRestoringModel;}
 
-  void fetchExtendsModifiers(QString extendsClass);
-  void reDrawModelWidgetInheritedClasses();
-  void drawModelCoOrdinateSystem(GraphicsView *pGraphicsView);
   void drawModelIconDiagramShapes(QStringList shapes, GraphicsView *pGraphicsView, bool select);
-  ShapeAnnotation* createNonExistingInheritedShape(GraphicsView *pGraphicsView);
-  static ShapeAnnotation* createInheritedShape(ShapeAnnotation *pShapeAnnotation, GraphicsView *pGraphicsView);
-  Element* createInheritedComponent(Element *pComponent, GraphicsView *pGraphicsView);
-  LineAnnotation* createInheritedConnection(LineAnnotation *pConnectionLineAnnotation);
-  void loadElements();
 
   void drawModel(const ModelInfo &modelInfo);
   void drawModelIconDiagram(ModelInstance::Model *pModelInstance, bool inherited, const ModelInfo &modelInfo);
-
   void loadModelInstance(bool icon, const ModelInfo &modelInfo);
   void loadDiagramViewNAPI();
-  void loadDiagramView();
-  void loadConnections();
-  void getModelConnections();
   void detectMultipleDeclarations();
-  void addConnection(QStringList connectionList, QString connectionAnnotationString, bool addToOMC, bool select);
   void createModelWidgetComponents();
   ShapeAnnotation* drawOMSModelElement();
   void addUpdateDeleteOMSElementIcon(const QString &iconPath);
   Element* getConnectorElement(Element *pConnectorComponent, QString connectorName);
   void clearGraphicsViews();
+  void clearGraphicsViewsExceptOutOfSceneItems();
   void reDrawModelWidget();
   void reDrawModelWidget(const ModelInfo &modelInfo);
   bool validateText(LibraryTreeItem **pLibraryTreeItem);
@@ -626,13 +588,9 @@ public:
   void updateModelText();
   void callHandleCollidingConnectionsIfNeeded();
   void updateUndoRedoActions();
-  bool writeCoSimulationResultFile(QString fileName);
-  bool writeVisualXMLFile(QString fileName, bool canWriteVisualXMLFile = false);
   void beginMacro(const QString &text);
   void endMacro();
   void updateViewButtonsBasedOnAccess();
-  void associateBusWithConnector(QString busName, QString connectorName);
-  void dissociateBusWithConnector(QString busName, QString connectorName);
   void associateBusWithConnectors(QString busName);
   QList<QVariant> toOMSensData();
   void createOMSimulatorUndoCommand(const QString &commandText, const bool doSnapShot = true, const bool switchToEdited = true,
@@ -640,6 +598,9 @@ public:
   void createOMSimulatorRenameModelUndoCommand(const QString &commandText, const QString &cref, const QString &newCref);
   void processPendingModelUpdate();
   ModelInfo createModelInfo() const;
+  void showElement(ModelInstance::Model *pModelInstance, bool addToList);
+  void selectDeselectElement(const QString &name, bool selected);
+  void navigateToClass(const QString &className);
 private:
   ModelWidgetContainer *mpModelWidgetContainer;
   ModelInstance::Model *mpModelInstance;
@@ -649,6 +610,10 @@ private:
   QToolButton *mpTextViewToolButton;
   QToolButton *mpDocumentationViewToolButton;
   QButtonGroup *mpViewsButtonGroup;
+  QToolButton *mpBackToolButton;
+  QToolButton *mpForwardToolButton;
+  QToolButton *mpExitToolButton;
+  Label *mpElementModeLabel;
   Label *mpReadOnlyLabel;
   Label *mpModelicaTypeLabel;
   Label *mpViewTypeLabel;
@@ -663,66 +628,43 @@ private:
   QUndoView *mpUndoView;
   BaseEditor *mpEditor;
   QStatusBar *mpModelStatusBar;
-  bool mElementsLoaded;
   bool mDiagramViewLoaded;
-  bool mConnectionsLoaded;
   bool mCreateModelWidgetComponents;
   QVBoxLayout *mpMainLayout;
-  QString mIconAnnotationString;
-  QString mDiagramAnnotationString;
-  bool mExtendsModifiersLoaded;
-  QMap<QString, QMap<QString, QString> > mExtendsModifiersMap;
-  bool mDerivedClassModifiersLoaded;
-  QMap<QString, QString> mDerivedClassModifiersMap;
   QList<LibraryTreeItem*> mInheritedClassesList;
-  QMap<int, IconDiagramMap> mInheritedClassesIconMap;
-  QMap<int, IconDiagramMap> mInheritedClassesDiagramMap;
-  QList<ElementInfo*> mElementsList;
-  QStringList mElementsAnnotationsList;
   QTimer mUpdateModelTimer;
   QStringList mDependsOnModelsList;
-  bool mHasMissingType = false;
   bool mHandleCollidingConnectionsNeeded = false;
   bool mRequiresUpdate = false;
+  ModelInstance::Model *mpRootModelInstance;
+  QList<ModelInstance::Model*> mModelInstanceList;
+  int mModelInstancesPos = -1;
+  QList<ShapeAnnotation*> mPreservedIconShapesList;
+  QList<ShapeAnnotation*> mPreservedDiagramShapesList;
+  ModelInfo mModelInfo;
+  bool mComponentModified = false;
+  bool mRestoringModel = false;
 
   void createUndoStack();
   void handleCanUndoRedoChanged();
-  IconDiagramMap getIconDiagramMap(QString mapAnnotation);
-  void getModelInheritedClasses();
-  void drawModelInheritedClassShapes(ModelWidget *pModelWidget, StringHandler::ViewType viewType);
-
-  void getModelIconDiagramShapes(StringHandler::ViewType viewType);
-  void readCoOrdinateSystemFromInheritedClass(ModelWidget *pModelWidget, GraphicsView *pGraphicsView);
-  void drawModelInheritedClassComponents(ModelWidget *pModelWidget, StringHandler::ViewType viewType);
-  void getModelElements();
-  void drawModelIconElements();
-  void drawModelDiagramElements();
-  void drawModelInheritedClassConnections(ModelWidget *pModelWidget);
-  void getModelTransitions();
-  void getModelInitialStates();
-  void getMetaModelSubModels();
-  void getMetaModelConnections();
-  QString getCompositeModelName();
-  void getCompositeModelSubModels();
-  void getCompositeModelConnections();
   void drawOMSModelIconElements();
   void drawOMSModelDiagramElements();
   void drawOMSElement(LibraryTreeItem *pLibraryTreeItem, const QString &annotation);
   void drawOMSModelConnections();
-  void associateBusWithConnector(QString busName, QString connectorName, GraphicsView *pGraphicsView);
-  void dissociateBusWithConnector(QString busName, QString connectorName, GraphicsView *pGraphicsView);
   void associateBusWithConnectors(Element *pBusComponent, GraphicsView *pGraphicsView);
-  static void removeInheritedClasses(LibraryTreeItem *pLibraryTreeItem);
   bool dependsOnModel(const QString &modelName);
+  void updateElementModeButtons();
 private slots:
   void showIconView(bool checked);
   void showDiagramView(bool checked);
   void showTextView(bool checked);
+  void backElement();
+  void forwardElement();
+  void exitElement();
   void updateModel();
 public slots:
   void makeFileWritAble();
   void showDocumentationView();
-  bool compositeModelEditorTextChanged();
   void handleCanUndoChanged(bool canUndo);
   void handleCanRedoChanged(bool canRedo);
   void updateModelIfDependsOn(const QString &modelName);
@@ -748,13 +690,12 @@ public:
   bool isShowGridLines() {return mShowGridLines;}
   bool eventFilter(QObject *object, QEvent *event);
   void changeRecentModelsListSelection(bool moveDown);
-#if !defined(WITHOUT_OSG)
-  void updateThreeDViewer(ModelWidget *pModelWidget);
-#endif
   bool validateText();
-  void getOpenedModelWidgetsOfOMSimulatorModel(const QString &modelName, QStringList *pOpenedModelWidgetsList);
-  void getCurrentModelWidgetSelectedComponents(QStringList *pIconSelectedItemsList, QStringList *pDiagramSelectedItemsList);
-  void selectCurrentModelWidgetComponents(QStringList iconSelectedItemsList, QStringList diagramSelectedItemsList);
+  void getOpenedModelWidgetsAndSelectedElementsOfClass(const QString &modelName, QHash<QString, QPair<QStringList, QStringList> > *pOpenedModelWidgetsAndSelectedElements);
+  void openModelWidgetsAndSelectElement(QHash<QString, QPair<QStringList, QStringList> > closedModelWidgetsAndSelectedElements, bool skipSelection = false);
+
+  QRect mCopiedItemsBoundingRect;
+  QPointF mCursorPositionAtCopy;
 private:
   StringHandler::ViewType mPreviousViewType;
   bool mShowGridLines;
@@ -765,14 +706,11 @@ private:
 public slots:
   bool openRecentModelWidget(QListWidgetItem *pListWidgetItem);
   void currentModelWidgetChanged(QMdiSubWindow *pSubWindow);
-  void updateThreeDViewer(QMdiSubWindow *pSubWindow);
   void saveModelWidget();
   void saveAsModelWidget();
   void saveTotalModelWidget();
   void printModel();
   void fitToDiagram();
-  void showSimulationParams();
-  void alignInterfaces();
   void addSystem();
   void addOrEditIcon();
   void deleteIcon();
