@@ -153,11 +153,8 @@ public:
   QList<QList<QString> > getTransitions(QString className);
   QList<QList<QString> > getInitialStates(QString className);
   int getInheritanceCount(QString className);
-  QString getNthInheritedClass(QString className, int num);
   QList<QString> getInheritedClasses(QString className);
-  QString getNthInheritedClassIconMapAnnotation(QString className, int num);
-  QString getNthInheritedClassDiagramMapAnnotation(QString className, int num);
-  QList<ElementInfo*> getElements(QString className);
+  QList<ElementInfo> getElements(QString className);
   QStringList getElementAnnotations(QString className);
   QString getDocumentationAnnotationInfoHeader(LibraryTreeItem *pLibraryTreeItem, QString infoHeader);
   QString getDocumentationAnnotation(LibraryTreeItem *pLibraryTreeItem);
@@ -165,9 +162,9 @@ public:
   QString getClassComment(QString className);
   QString changeDirectory(QString directory = QString(""));
   bool loadModel(QString className, QString priorityVersion = QString("default"), bool notify = true, QString languageStandard = QString(""), bool requireExactVersion = false);
-  bool loadFile(QString fileName, QString encoding = Helper::utf8, bool uses = true, bool notify = true, bool requireExactVersion = false);
+  bool loadFile(QString fileName, QString encoding = Helper::utf8, bool uses = true, bool notify = true, bool requireExactVersion = false, bool allowWithin = false);
   bool loadString(QString value, QString fileName, QString encoding = Helper::utf8, bool merge = false, bool checkError = true);
-  bool loadClassContentString(const QString &data, const QString &className);
+  bool loadClassContentString(const QString &data, const QString &className, int offsetX = 0, int offsetY = 0);
   QList<QString> parseFile(QString fileName, QString encoding = Helper::utf8);
   QList<QString> parseString(QString value, QString fileName, bool printErrors = true);
   bool createClass(QString type, QString className, LibraryTreeItem *pExtendsLibraryTreeItem);
@@ -177,20 +174,17 @@ public:
   bool deleteClass(QString className);
   QString getSourceFile(QString className);
   bool setSourceFile(QString className, QString path);
-  bool save(QString className);
-  bool saveModifiedModel(QString modelText);
   bool saveTotalModel(QString fileName, QString className, bool stripAnnotations, bool stripComments, bool obfuscate, bool simplified);
   QString list(QString className);
   QString listFile(QString className, bool nestedClasses = true);
   QString diffModelicaFileListings(const QString &before, const QString &after);
   QString instantiateModel(QString className);
+  QString runScript(QString fileName);
   bool addClassAnnotation(QString className, QString annotation);
   QString getDefaultComponentName(QString className);
   QString getDefaultComponentPrefixes(QString className);
   bool addComponent(QString name, QString componentName, QString className, QString placementAnnotation);
   bool deleteComponent(QString name, QString componentName);
-  bool renameComponent(QString className, QString oldName, QString newName);
-  bool updateComponent(QString name, QString className, QString componentName, QString placementAnnotation);
   bool setElementAnnotation(const QString &elementName, QString annotation);
   bool renameComponentInClass(QString className, QString oldName, QString newName);
   bool updateConnection(QString className, QString from, QString to, QString annotation);
@@ -208,8 +202,6 @@ public:
   bool addInitialState(QString className, QString state, QString annotation);
   bool deleteInitialState(QString className, QString state);
   bool updateInitialState(QString className, QString state, QString annotation);
-  bool simulate(QString className, QString simualtionParameters);
-  bool buildModel(QString className, QString simualtionParameters);
   bool translateModel(QString className, QString simualtionParameters);
   int readSimulationResultSize(QString fileName);
   QStringList readSimulationResultVars(QString fileName);
@@ -220,6 +212,7 @@ public:
   bool isExperiment(QString className);
   OMCInterface::getSimulationOptions_res getSimulationOptions(QString className, double defaultTolerance = 1e-6);
   QString buildModelFMU(QString className, QString version, QString type, QString fileNamePrefix, QList<QString> platforms, bool includeResources);
+  bool translateModelFMU(QString className, QString version, QString type, QString fileNamePrefix, QList<QString> platforms, bool includeResources);
   QString translateModelXML(QString className);
   QString importFMU(QString fmuName, QString outputDirectory, int logLevel, bool debugLogging, bool generateInputConnectors, bool generateOutputConnectors, QString modelName);
   QString importFMUModelDescription(QString fmuModelDescriptionName, QString outputDirectory, int logLevel, bool debugLogging, bool generateInputConnectors, bool generateOutputConnectors);
@@ -241,8 +234,6 @@ public:
   QString getHomeDirectoryPath();
   QStringList getAvailableLibraries();
   QStringList getAvailableLibraryVersions(QString libraryName);
-  QStringList getDerivedClassModifierNames(QString className);
-  QString getDerivedClassModifierValue(QString className, QString modifierName);
   OMCInterface::convertUnits_res convertUnits(QString from, QString to);
   QList<QString> getDerivedUnits(QString baseUnit);
   QString getNamedAnnotation(const QString &className, const QString &annotation, StringHandler::ResultType type = StringHandler::String);
