@@ -554,7 +554,7 @@ void AddBusDialog::addBus()
       }
     }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     QSet<QString> connectorsSet(connectors.begin(), connectors.end());
     QSet<QString> existingConnectorsSet(existingConnectors.begin(), existingConnectors.end());
     QSet<QString> addConnectors = connectorsSet.subtract(existingConnectorsSet);
@@ -578,8 +578,8 @@ void AddBusDialog::addBus()
     if (OMSProxy::instance()->addBus(bus)) {
       if (mpGraphicsView->mContextMenuStartPositionValid) {
         ssd_connector_geometry_t connectorGeometry;
-        connectorGeometry.x = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.x(), -100, 100, 0, 1);
-        connectorGeometry.y = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.y(), -100, 100, 0, 1);
+        connectorGeometry.x = Utilities::mapToCoordinateSystem(mpGraphicsView->mContextMenuStartPosition.x(), -100, 100, 0, 1);
+        connectorGeometry.y = Utilities::mapToCoordinateSystem(mpGraphicsView->mContextMenuStartPosition.y(), -100, 100, 0, 1);
         OMSProxy::instance()->setBusGeometry(bus, &connectorGeometry);
       }
       foreach (QString connector, connectors) {
@@ -877,8 +877,8 @@ void AddTLMBusDialog::addTLMBus()
                                         (oms_tlm_interpolation_t)mpInterpolationComboBox->itemData(mpInterpolationComboBox->currentIndex()).toInt())) {
       if (mpGraphicsView->mContextMenuStartPositionValid) {
         ssd_connector_geometry_t connectorGeometry;
-        connectorGeometry.x = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.x(), -100, 100, 0, 1);
-        connectorGeometry.y = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.y(), -100, 100, 0, 1);
+        connectorGeometry.x = Utilities::mapToCoordinateSystem(mpGraphicsView->mContextMenuStartPosition.x(), -100, 100, 0, 1);
+        connectorGeometry.y = Utilities::mapToCoordinateSystem(mpGraphicsView->mContextMenuStartPosition.y(), -100, 100, 0, 1);
         OMSProxy::instance()->setTLMBusGeometry(tlmBus, &connectorGeometry);
       }
       // add connectors to the bus
@@ -1174,7 +1174,7 @@ QMimeData* ConnectionsModel::mimeData(const QModelIndexList &indexes) const
   return mimeData;
 }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
 bool ConnectionsModel::canDropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) const
 {
   Q_UNUSED(action);
@@ -1602,7 +1602,6 @@ void BusConnectionDialog::deleteAtomicConnection(QString startConnectorName, QSt
 
     foreach (LineAnnotation *pConnectionLineAnnotation, mpGraphicsView->getConnectionsList()) {
       if ((pConnectionLineAnnotation->getStartElementName().compare(startComponentName) == 0) && (pConnectionLineAnnotation->getEndElementName().compare(endComponentName) == 0)) {
-        mpGraphicsView->removeConnectionFromView(pConnectionLineAnnotation);
         mpGraphicsView->deleteConnectionFromClass(pConnectionLineAnnotation);
       }
     }
@@ -1659,11 +1658,11 @@ void BusConnectionDialog::addAtomicConnection(QString startConnectorName, QStrin
     pNewConnectionLineAnnotation->setEndElement(pEndComponent);
     pNewConnectionLineAnnotation->setEndElementName(endComponentName);
 
-    mpGraphicsView->addConnectionToView(pNewConnectionLineAnnotation, false);
     if (mpGraphicsView->addConnectionToClass(pNewConnectionLineAnnotation) && pStartLibraryTreeItem->getOMSBusConnector() && pEndLibraryTreeItem->getOMSBusConnector()) {
+      mpGraphicsView->addConnectionToView(pNewConnectionLineAnnotation, false);
       pNewConnectionLineAnnotation->setVisible(false);
     } else {
-      mpGraphicsView->removeConnectionFromView(pNewConnectionLineAnnotation);
+      pNewConnectionLineAnnotation->deleteLater();
     }
   }
 }
