@@ -48,14 +48,6 @@
 #include <QColorDialog>
 #include <QDir>
 #include <QRegExp>
-#ifdef OM_OMEDIT_ENABLE_LIBXML2
-#include <libxml/parser.h>
-#include <libxml/valid.h>
-#else
-#include <QXmlSchema>
-#include <QXmlSchemaValidator>
-#endif
-
 
 extern "C" {
 extern const char* System_openModelicaPlatform();
@@ -256,7 +248,7 @@ Label::Label(const QString &text, QWidget *parent, Qt::WindowFlags flags)
 
 QSize Label::minimumSizeHint() const
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
   if (!pixmap(Qt::ReturnByValue).isNull() || mElideMode == Qt::ElideNone) {
 #else // QT_VERSION_CHECK
   if (pixmap() != NULL || mElideMode == Qt::ElideNone) {
@@ -264,7 +256,7 @@ QSize Label::minimumSizeHint() const
     return QLabel::minimumSizeHint();
   }
   const QFontMetrics &fm = fontMetrics();
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
   QSize size(fm.horizontalAdvance("..."), fm.height()+5);
 #else // QT_VERSION_CHECK
   QSize size(fm.width("..."), fm.height()+5);
@@ -274,7 +266,7 @@ QSize Label::minimumSizeHint() const
 
 QSize Label::sizeHint() const
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
   if (!pixmap(Qt::ReturnByValue).isNull() || mElideMode == Qt::ElideNone) {
 #else // QT_VERSION_CHECK
   if (pixmap() != NULL || mElideMode == Qt::ElideNone) {
@@ -282,7 +274,7 @@ QSize Label::sizeHint() const
     return QLabel::sizeHint();
   }
   const QFontMetrics& fm = fontMetrics();
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
   QSize size(fm.horizontalAdvance(mText), fm.height()+5);
 #else // QT_VERSION_CHECK
   QSize size(fm.width(mText), fm.height()+5);
@@ -318,6 +310,51 @@ void Label::resizeEvent(QResizeEvent *event)
   QLabel::setText(elidedText());
 }
 
+ComboBox::ComboBox(QWidget *parent)
+  : QComboBox(parent)
+{
+  setFocusPolicy(Qt::StrongFocus);
+}
+
+void ComboBox::wheelEvent(QWheelEvent *event)
+{
+  if (!hasFocus()) {
+    event->ignore();
+  } else {
+    QComboBox::wheelEvent(event);
+  }
+}
+
+SpinBox::SpinBox(QWidget *parent)
+  : QSpinBox(parent)
+{
+  setFocusPolicy(Qt::StrongFocus);
+}
+
+void SpinBox::wheelEvent(QWheelEvent *event)
+{
+  if (!hasFocus()) {
+    event->ignore();
+  } else {
+    QSpinBox::wheelEvent(event);
+  }
+}
+
+DoubleSpinBox::DoubleSpinBox(QWidget *parent)
+  : QDoubleSpinBox(parent)
+{
+  setFocusPolicy(Qt::StrongFocus);
+}
+
+void DoubleSpinBox::wheelEvent(QWheelEvent *event)
+{
+  if (!hasFocus()) {
+    event->ignore();
+  } else {
+    QDoubleSpinBox::wheelEvent(event);
+  }
+}
+
 FixedCheckBox::FixedCheckBox(QWidget *parent)
  : QCheckBox(parent)
 {
@@ -459,7 +496,7 @@ void QDetachableProcess::start(const QString &program, const QStringList &argume
   setProcessState(QProcess::NotRunning);
 }
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 /*!
  * \brief QDetachableProcess::start
  * Starts a process and detaches from it.
@@ -624,74 +661,13 @@ QSettings* Utilities::getApplicationSettings()
   if (!init) {
     init = 1;
     pSettings = new QSettings(QSettings::IniFormat, QSettings::UserScope, Helper::organization, Helper::application);
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     pSettings->setIniCodec(Helper::utf8.toUtf8().constData());
 #endif
   }
   return pSettings;
 }
 
-
-/*!
- * \brief Utilities::parseCompositeModelText
- * Parses the CompositeModel text against the schema.
- * \param pMessageHandler
- * \param contents
- */
-void Utilities::parseCompositeModelText(MessageHandler *pMessageHandler, QString contents)
-{
-  QFile schemaFile(QString(":/Resources/XMLSchema/tlmModelDescription.xsd"));
-  schemaFile.open(QIODevice::ReadOnly);
-  const QString schemaText(QString::fromUtf8(schemaFile.readAll()));
-  schemaFile.close();
-  const QByteArray schemaData = schemaText.toUtf8();
-
-#ifdef OM_OMEDIT_ENABLE_LIBXML2
-  xmlDocPtr doc;
-  QByteArray contentsArray(contents.toLocal8Bit());
-  doc = xmlParseDoc((const xmlChar *)contentsArray.data());
-  if (doc)
-  {
-    xmlParserInputBufferPtr buf = xmlParserInputBufferCreateMem(schemaData.data(), schemaData.size(), XML_CHAR_ENCODING_UTF8);
-    xmlDtdPtr dtd = xmlIOParseDTD(NULL, buf, XML_CHAR_ENCODING_UTF8);
-    xmlFreeParserInputBuffer(buf);
-    if (dtd)
-    {
-      xmlValidCtxtPtr vctxt;
-      vctxt = xmlNewValidCtxt();
-      if (vctxt)
-      {
-        int ok = xmlValidateDtd(vctxt, doc, dtd);
-        if (!ok)
-          pMessageHandler->setFailed(true);
-        xmlFreeValidCtxt(vctxt);
-      }
-      else
-        pMessageHandler->setFailed(true);
-      xmlFreeDtd(dtd);
-    }
-    else
-      pMessageHandler->setFailed(true);
-    xmlFreeDoc(doc);
-  }
-  else
-      pMessageHandler->setFailed(true);
-
-#else
-  QXmlSchema schema;
-  schema.setMessageHandler(pMessageHandler);
-  schema.load(schemaData);
-  if (!schema.isValid()) {
-    pMessageHandler->setFailed(true);
-  } else {
-    QXmlSchemaValidator validator(schema);
-    if (!validator.validate(contents.toUtf8())) {
-      pMessageHandler->setFailed(true);
-    }
-  }
-#endif
-}
-
 /*!
  * \brief Utilities::convertUnit
  * Converts the value using the unit offset and scale factor.
@@ -720,6 +696,20 @@ bool Utilities::isValueLiteralConstant(QString value)
   return rx.exactMatch(value);
 }
 
+/*!
+ * \brief Utilities::isValueScalarLiteralConstant
+ * \param value
+ * \return
+ */
+bool Utilities::isValueScalarLiteralConstant(QString value)
+{
+  /* Issue #13636
+   * Check if value is scalar and literal constant.
+   */
+  QRegExp rx("\\s*-?\\d+(\\.\\d+)?([eE][-+]?\\d+)?");
+  return rx.exactMatch(value);
+}
+
 /*!
  * \brief Utilities::arrayExpressionUnitConversion
  * If the expression is like an array of constants see ticket:4840
@@ -898,7 +888,7 @@ void Utilities::highlightParentheses(QPlainTextEdit *pPlainTextEdit, QTextCharFo
 qint64 Utilities::getProcessId(QProcess *pProcess)
 {
   qint64 processId = 0;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 3, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 3, 0)
   processId = pProcess->processId();
 #else /* Qt4 */
 #if defined(_WIN32)
@@ -1018,31 +1008,6 @@ bool Utilities::isModelicaFile(QString extension)
   }
 }
 
-/*!
- * \brief Utilities::getRotationMatrix
- * Computes the corresponding rotation matrix for specified rotation vector
- * \param rotation Rotation vector with Euler angles
- * \return
- */
-QGenericMatrix<3,3, double> Utilities::getRotationMatrix(QGenericMatrix<3,1,double> rotation)
-{
-  double c1 = cos(rotation(0,0));
-  double s1 = sin(rotation(0,0));
-  double c2 = cos(rotation(0,1));
-  double s2 = sin(rotation(0,1));
-  double c3 = cos(rotation(0,2));
-  double s3 = sin(rotation(0,2));
-
-  double R_data[9];
-  R_data[0] = c2*c3;             R_data[1] = c2*s3;              R_data[2] = -s2;
-  R_data[3] = -c1*s3+s1*s2*c3;   R_data[4] = c1*c3+s1*s2*s3;     R_data[5] = s1*c2;
-  R_data[6] = s1*s3+c1*s2*c3;    R_data[7] = -s1*c3+c1*s2*s3;    R_data[8] = c1*c2;
-
-  QGenericMatrix<3,3,double> R(R_data);
-
-  return R;
-}
-
 QString Utilities::getGDBPath()
 {
 #if defined(_WIN32)
@@ -1092,7 +1057,7 @@ QIcon Utilities::FileIconProvider::FileIconProviderImplementation::icon(const QF
   // Get icon from OS.
   QIcon icon;
   // File icons are unknown on linux systems.
-#if defined(Q_OS_LINUX)
+#if defined(Q_OS_UNIX)
   icon = isDir ? QFileIconProvider::icon(fileInfo) : mUnknownFileIcon;
 #else
   icon = QFileIconProvider::icon(fileInfo);
@@ -1235,18 +1200,18 @@ QList<QPointF> Utilities::liangBarskyClipper(float xmin, float ymin, float xmax,
 }
 
 /*!
- * \brief Utilities::removeDirectoryRecursivly
+ * \brief Utilities::removeDirectoryRecursively
  * Removes the directory recursively.
  * \param path
  */
-void Utilities::removeDirectoryRecursivly(QString path)
+void Utilities::removeDirectoryRecursively(QString path)
 {
   QFileInfo fileInfo(path);
   if (fileInfo.isDir()) {
     QDir dir(path);
     QStringList filesList = dir.entryList(QDir::AllDirs | QDir::Files | QDir::NoSymLinks | QDir::NoDotAndDotDot | QDir::Writable | QDir::CaseSensitive);
     for (int i = 0 ; i < filesList.count() ; ++i) {
-      removeDirectoryRecursivly(QString("%1/%2").arg(path, filesList.at(i)));
+      removeDirectoryRecursively(QString("%1/%2").arg(path, filesList.at(i)));
     }
     QDir().rmdir(path);
   } else {
@@ -1255,7 +1220,7 @@ void Utilities::removeDirectoryRecursivly(QString path)
 }
 
 /*!
- * \brief Utilities::mapToCoOrdinateSystem
+ * \brief Utilities::mapToCoordinateSystem
  * If you have numbers x in the range [a,b] and you want to transform them to numbers y in the range [c,d].\n
  * y = ((x−a) * ((d−c)/(b−a))) + c
  * \param value
@@ -1265,7 +1230,7 @@ void Utilities::removeDirectoryRecursivly(QString path)
  * \param endB
  * \return
  */
-qreal Utilities::mapToCoOrdinateSystem(qreal value, qreal startA, qreal endA, qreal startB, qreal endB)
+qreal Utilities::mapToCoordinateSystem(qreal value, qreal startA, qreal endA, qreal startB, qreal endB)
 {
   return ((value - startA) * ((endB - startB) / (endA - startA))) + startB;
 }
@@ -1288,22 +1253,28 @@ void Utilities::addDefaultDisplayUnit(const QString &unit, QStringList &displayU
 {
   /* Issue #5447
    * For angular speeds always add in the menu in the unit column, in addition to the standard "rad/s" also "rpm"
-   * For energies always add in the menu in the Display Unit column, in addition to standard "J", also "Wh" (prefixes such as kWh, MWh, GWh will be obtained automatically)
-   */
-  /* Issue #8758
-   * Whenever unit = "K", we also add "degC" even if it is not defined as displayUnits.
-   */
-  /* Issue #12340
-   * Whenever unit = "m/s", we also add "km/h" even if it is not defined as displayUnits.
+   * For energies always add in the menu in the Unit column, in addition to standard "J", also "Wh" (prefixes such as kWh, MWh, GWh will be obtained automatically)
    */
   if (unit.compare(QStringLiteral("rad/s")) == 0) {
     displayUnit << "rpm";
   } else if (unit.compare(QStringLiteral("J")) == 0) {
     displayUnit << "Wh";
   } else if (unit.compare(QStringLiteral("K")) == 0) {
+    /* Issue #8758
+     * Whenever unit = "K", we also add "degC" even if it is not defined as displayUnits.
+     */
     displayUnit << "degC";
   } else if (unit.compare(QStringLiteral("m/s")) == 0) {
+    /* Issue #12340
+     * Whenever unit = "m/s", we also add "km/h" even if it is not defined as displayUnits.
+     */
     displayUnit << "km/h";
+  } else if (unit.compare(QStringLiteral("m3/s")) == 0) {
+    /* Issue #13379
+     * For volume flow rate it would be good to have extra display units l/s, which is 0.001 m3/s, and maybe also m3/h, which is 1/3600 m3/s.
+     * Whenever unit = "m3/s", we also add "l/s" and "m3/h" even if it is not defined as displayUnits.
+     */
+    displayUnit << "l/s" << "m3/h";
   }
 }
 
@@ -1400,3 +1371,28 @@ bool Utilities::isMultiline(const QString &text)
 {
   return text.indexOf('\n') >= 0;
 }
+
+/*!
+ * \brief Utilities::supportedLanguages
+ * Returns the map of languages that OMEdit support.
+ * \return
+ */
+QMap<QString, QLocale> Utilities::supportedLanguages()
+{
+  static int init = 0;
+  static QMap<QString, QLocale> languagesMap;
+  if (!init) {
+    init = 1;
+    languagesMap.insert(QObject::tr("Chinese").append(" (zh_CN)"), QLocale(QLocale::Chinese));
+    languagesMap.insert(QObject::tr("English").append(" (en)"), QLocale(QLocale::English));
+    languagesMap.insert(QObject::tr("French").append(" (fr)"), QLocale(QLocale::French));
+    languagesMap.insert(QObject::tr("German").append(" (de)"), QLocale(QLocale::German));
+    languagesMap.insert(QObject::tr("Italian").append(" (it)"), QLocale(QLocale::Italian));
+    languagesMap.insert(QObject::tr("Japanese").append(" (ja)"), QLocale(QLocale::Japanese));
+    languagesMap.insert(QObject::tr("Romanian").append(" (ro)"), QLocale(QLocale::Romanian));
+    languagesMap.insert(QObject::tr("Russian").append(" (ru)"), QLocale(QLocale::Russian));
+    languagesMap.insert(QObject::tr("Spanish").append(" (es)"), QLocale(QLocale::Spanish));
+    languagesMap.insert(QObject::tr("Swedish").append(" (sv)"), QLocale(QLocale::Swedish));
+  }
+  return languagesMap;
+}
