@@ -260,7 +260,7 @@ OMS::OMS( QWidget* parent )
   // create command compleation instance
   QString openmodelica( delegate_->OpenModelicaHome() );
   if( openmodelica.isEmpty() )
-    QMessageBox::critical( 0, "OMShell Error", "Could not find installation directory path, command completion will not work. Please make sure OpenModelica is installed properly." );
+    QMessageBox::critical(nullptr, "OMShell Error", "Could not find installation directory path, command completion will not work. Please make sure OpenModelica is installed properly." );
 
   try
   {
@@ -276,11 +276,15 @@ OMS::OMS( QWidget* parent )
   {
     QString msg = e.what();
     msg += "\nCould not create command completion class!";
-    QMessageBox::warning( 0, "Error", msg, "OK" );
+    QMessageBox::warning(nullptr, "Error", msg);
   }
 
   // command stuff
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+  commandSignFormat_.setFontFamilies({"Arial"});
+#else
   commandSignFormat_.setFontFamily( "Arial" );
+#endif
   commandSignFormat_.setFontWeight( QFont::Bold );
   commandSignFormat_.setFontPointSize( fontSize_ );
 
@@ -445,7 +449,11 @@ void OMS::addCommandLine()
 
   // set original text settings
   moshEdit_->document()->setDefaultFont(QFont("Courier New", fontSize_, QFont::Normal));
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+  textFormat_.setFontFamilies({"Courier New"});
+#else
   textFormat_.setFontFamily( "Courier New" );
+#endif
   textFormat_.setFontWeight( QFont::Normal );
   textFormat_.setFontPointSize( fontSize_ );
 
