@@ -62,6 +62,9 @@ oms::Model::~Model()
   if (system)
     delete system;
 
+  for (auto const & variant : ssdVariants)
+    free(variant.second);
+
   // delete temp directory
   if (Flags::DeleteTempFiles())
   {
@@ -200,6 +203,13 @@ oms_status_enu_t oms::Model::duplicateVariant(const ComRef& crefA, const ComRef&
   Snapshot snapshot;
   snapshot.import(fullsnapshot);
 
+  {
+    auto it = ssdVariants.find(snapshot.getRootCref());
+    if (it != ssdVariants.end())
+    {
+      free(ssdVariants[snapshot.getRootCref()]);
+    }
+  }
   ssdVariants[snapshot.getRootCref()] = fullsnapshot;
 
   // rename the model and all it components to new variant name
@@ -254,6 +264,7 @@ oms_status_enu_t oms::Model::activateVariant(const ComRef& crefA, const ComRef&
       variants.writeDocument(&modifiedVariant);
       char * newCref = NULL;
       importSnapshot(modifiedVariant, &newCref);
+      free(modifiedVariant);
       return oms_status_ok;
     }
   }
@@ -271,6 +282,7 @@ oms_status_enu_t oms::Model::listVariants(const oms::ComRef& cref, char** conten
   exportSnapshot("", &fullsnapshot);
   Snapshot currentSnapshot;
   currentSnapshot.import(fullsnapshot);
+  free(fullsnapshot);
 
   pugi::xml_node oms_Variants = allVariantSnapshot.getTemplateResourceNodeSSDVariants();
 
@@ -849,7 +861,9 @@ oms_status_enu_t oms::Model::exportToSSD(Snapshot& snapshot) const
   oms_simulation_information.append_attribute("resultFile") = resultFilename.c_str();
   oms_simulation_information.append_attribute("loggingInterval") = std::to_string(loggingInterval).c_str();
   oms_simulation_information.append_attribute("bufferSize") = std::to_string(bufferSize).c_str();
-  oms_simulation_information.append_attribute("signalFilter") = signalFilterFilename.c_str();
+  // check for root system exist and export signalFilter
+  if (system)
+    oms_simulation_information.append_attribute("signalFilter") = signalFilterFilename.c_str();
 
   return oms_status_ok;
 }
@@ -1576,6 +1590,10 @@ std::string oms::Model::escapeSpecialCharacters(const std::string& regex)
 
 oms_status_enu_t oms::Model::importSignalFilter(const std::string& filename, const Snapshot& snapshot)
 {
+  // check for system and do not import signalFilter if system == NULL
+  if (!system)
+    return oms_status_ok;
+
   if (".*" == filename) // avoid error messages for older ssp files
   {
     addSignalsToResults(".*");
